"""
tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver.nationalities_double_v2 import resolve_by_nats_double_v2

male_tests = {
    "sri lankan tamil descent": "أصل تاميلي سريلانكي",
    "jewish german history": "تاريخ ألماني يهودي",
    "german jewish history": "تاريخ ألماني يهودي",
    "afghan jewish descent": "أصل أفغاني يهودي",
    "afghan-jewish descent": "أصل أفغاني يهودي",
    "african jewish descent": "أصل إفريقي يهودي",
    "african jewish diaspora": "شتات إفريقي يهودي",
    "african-jewish descent": "أصل إفريقي يهودي",
    "african-jewish diaspora": "شتات إفريقي يهودي",
    "algerian jewish descent": "أصل جزائري يهودي",
    "algerian jewish diaspora": "شتات جزائري يهودي",
    "algerian-jewish descent": "أصل جزائري يهودي",
    "algerian-jewish diaspora": "شتات جزائري يهودي",
    "american jewish descent": "أصل أمريكي يهودي",
    "american jewish diaspora": "شتات أمريكي يهودي",
    "american-jewish descent": "أصل أمريكي يهودي",
    "american-jewish diaspora": "شتات أمريكي يهودي",
    "argentine jewish descent": "أصل أرجنتيني يهودي",
    "argentine jewish diaspora": "شتات أرجنتيني يهودي",
    "argentine-jewish descent": "أصل أرجنتيني يهودي",
    "argentine-jewish diaspora": "شتات أرجنتيني يهودي",
    "armenian jewish descent": "أصل أرميني يهودي",
    "armenian-jewish descent": "أصل أرميني يهودي",
    "asian jewish descent": "أصل آسيوي يهودي",
    "asian jewish diaspora": "شتات آسيوي يهودي",
    "asian south african": "آسيويون جنوب إفريقيون",
    "asian-jewish descent": "أصل آسيوي يهودي",
    "asian-jewish diaspora": "شتات آسيوي يهودي",
    "australian jewish descent": "أصل أسترالي يهودي",
    "australian jewish diaspora": "شتات أسترالي يهودي",
    "australian-jewish descent": "أصل أسترالي يهودي",
    "australian-jewish diaspora": "شتات أسترالي يهودي",
    "austrian jewish descent": "أصل نمساوي يهودي",
    "austrian jewish diaspora": "شتات نمساوي يهودي",
    "austrian-jewish descent": "أصل نمساوي يهودي",
    "austrian-jewish diaspora": "شتات نمساوي يهودي",
    "azerbaijani jewish descent": "أصل أذربيجاني يهودي",
    "azerbaijani-jewish descent": "أصل أذربيجاني يهودي",
    "belarusian jewish descent": "أصل بيلاروسي يهودي",
    "belarusian jewish diaspora": "شتات بيلاروسي يهودي",
    "belarusian-jewish descent": "أصل بيلاروسي يهودي",
    "belarusian-jewish diaspora": "شتات بيلاروسي يهودي",
    "belgian jewish descent": "أصل بلجيكي يهودي",
    "belgian-jewish descent": "أصل بلجيكي يهودي",
    "bosnia and herzegovina jewish descent": "أصل بوسني يهودي",
    "bosnia and herzegovina-jewish descent": "أصل بوسني يهودي",
    "brazilian jewish descent": "أصل برازيلي يهودي",
    "brazilian jewish diaspora": "شتات برازيلي يهودي",
    "brazilian-jewish descent": "أصل برازيلي يهودي",
    "brazilian-jewish diaspora": "شتات برازيلي يهودي",
    "british jewish descent": "أصل بريطاني يهودي",
    "british jewish diaspora": "شتات بريطاني يهودي",
    "british-jewish descent": "أصل بريطاني يهودي",
    "british-jewish diaspora": "شتات بريطاني يهودي",
    "bulgarian jewish descent": "أصل بلغاري يهودي",
    "bulgarian jewish diaspora": "شتات بلغاري يهودي",
    "bulgarian-jewish descent": "أصل بلغاري يهودي",
    "bulgarian-jewish diaspora": "شتات بلغاري يهودي",
    "burmese jewish descent": "أصل بورمي يهودي",
    "burmese-jewish descent": "أصل بورمي يهودي",
    "cameroonian jewish descent": "أصل كاميروني يهودي",
    "cameroonian-jewish descent": "أصل كاميروني يهودي",
    "canadian jewish descent": "أصل كندي يهودي",
    "canadian jewish diaspora": "شتات كندي يهودي",
    "canadian-jewish descent": "أصل كندي يهودي",
    "canadian-jewish diaspora": "شتات كندي يهودي",
    "chilean jewish descent": "أصل تشيلي يهودي",
    "chilean-jewish descent": "أصل تشيلي يهودي",
    "chinese canadians": "صينيون كنديون",
    "chinese jewish descent": "أصل صيني يهودي",
    "chinese jewish diaspora": "شتات صيني يهودي",
    "chinese-jewish descent": "أصل صيني يهودي",
    "chinese-jewish diaspora": "شتات صيني يهودي",
    "colombian jewish descent": "أصل كولومبي يهودي",
    "colombian-jewish descent": "أصل كولومبي يهودي",
    "coptic british": "أقباط بريطانيون",
    "costa rican jewish descent": "أصل كوستاريكي يهودي",
    "costa rican-jewish descent": "أصل كوستاريكي يهودي",
    "croatian jewish descent": "أصل كرواتي يهودي",
    "croatian-jewish descent": "أصل كرواتي يهودي",
    "cuban jewish descent": "أصل كوبي يهودي",
    "cuban-jewish descent": "أصل كوبي يهودي",
    "czech jewish descent": "أصل تشيكي يهودي",
    "czech jewish diaspora": "شتات تشيكي يهودي",
    "czech-jewish descent": "أصل تشيكي يهودي",
    "czech-jewish diaspora": "شتات تشيكي يهودي",
    "czechoslovak jewish descent": "أصل تشيكوسلوفاكي يهودي",
    "czechoslovak-jewish descent": "أصل تشيكوسلوفاكي يهودي",
    "danish jewish descent": "أصل دنماركي يهودي",
    "danish-jewish descent": "أصل دنماركي يهودي",
    "dutch jewish descent": "أصل هولندي يهودي",
    "dutch jewish diaspora": "شتات هولندي يهودي",
    "dutch-jewish descent": "أصل هولندي يهودي",
    "dutch-jewish diaspora": "شتات هولندي يهودي",
    "egyptian jewish descent": "أصل مصري يهودي",
    "egyptian jewish diaspora": "شتات مصري يهودي",
    "egyptian-jewish descent": "أصل مصري يهودي",
    "egyptian-jewish diaspora": "شتات مصري يهودي",
    "english jewish descent": "أصل إنجليزي يهودي",
    "english jewish diaspora": "شتات إنجليزي يهودي",
    "english-jewish descent": "أصل إنجليزي يهودي",
    "english-jewish diaspora": "شتات إنجليزي يهودي",
    "estonian jewish descent": "أصل إستوني يهودي",
    "estonian-jewish descent": "أصل إستوني يهودي",
    "ethiopian jewish descent": "أصل إثيوبي يهودي",
    "ethiopian jewish diaspora": "شتات إثيوبي يهودي",
    "ethiopian-jewish descent": "أصل إثيوبي يهودي",
    "ethiopian-jewish diaspora": "شتات إثيوبي يهودي",
    "european jewish descent": "أصل أوروبي يهودي",
    "european jewish diaspora": "شتات أوروبي يهودي",
    "european-jewish descent": "أصل أوروبي يهودي",
    "european-jewish diaspora": "شتات أوروبي يهودي",
    "finnish jewish descent": "أصل فنلندي يهودي",
    "finnish-jewish descent": "أصل فنلندي يهودي",
    "french jewish descent": "أصل فرنسي يهودي",
    "french jewish diaspora": "شتات فرنسي يهودي",
    "french-jewish descent": "أصل فرنسي يهودي",
    "french-jewish diaspora": "شتات فرنسي يهودي",
    "georgian jewish descent": "أصل جورجي يهودي",
    "georgian-jewish descent": "أصل جورجي يهودي",
    "german jewish descent": "أصل ألماني يهودي",
    "german jewish diaspora": "شتات ألماني يهودي",
    "german romanian descent": "أصل ألماني روماني",
    "german-jewish descent": "أصل ألماني يهودي",
    "german-jewish diaspora": "شتات ألماني يهودي",
    "greek jewish descent": "أصل يهودي يوناني",
    "greek jewish diaspora": "شتات يهودي يوناني",
    "greek-jewish descent": "أصل يهودي يوناني",
    "greek-jewish diaspora": "شتات يهودي يوناني",
    "hungarian jewish descent": "أصل مجري يهودي",
    "hungarian jewish diaspora": "شتات مجري يهودي",
    "hungarian nazis": "مجريون نازيون",
    "hungarian-jewish descent": "أصل مجري يهودي",
    "hungarian-jewish diaspora": "شتات مجري يهودي",
    "indian jewish descent": "أصل هندي يهودي",
    "indian jewish diaspora": "شتات هندي يهودي",
    "indian-jewish descent": "أصل هندي يهودي",
    "indian-jewish diaspora": "شتات هندي يهودي",
    "iranian jewish descent": "أصل إيراني يهودي",
    "iranian jewish diaspora": "شتات إيراني يهودي",
    "iranian-jewish descent": "أصل إيراني يهودي",
    "iranian-jewish diaspora": "شتات إيراني يهودي",
    "iraqi jewish descent": "أصل عراقي يهودي",
    "iraqi jewish diaspora": "شتات عراقي يهودي",
    "iraqi-jewish descent": "أصل عراقي يهودي",
    "iraqi-jewish diaspora": "شتات عراقي يهودي",
    "irish jewish descent": "أصل أيرلندي يهودي",
    "irish-jewish descent": "أصل أيرلندي يهودي",
    "italian canadian culture": "ثقافة إيطالية كندية",
    "italian jewish descent": "أصل إيطالي يهودي",
    "italian jewish diaspora": "شتات إيطالي يهودي",
    "italian-jewish descent": "أصل إيطالي يهودي",
    "italian-jewish diaspora": "شتات إيطالي يهودي",
    "jamaican jewish descent": "أصل جامايكي يهودي",
    "jamaican-jewish descent": "أصل جامايكي يهودي",
    "jewish afghan history": "تاريخ أفغاني يهودي",
    "jewish albanian history": "تاريخ ألباني يهودي",
    "jewish algerian history": "تاريخ جزائري يهودي",
    "jewish angolan history": "تاريخ أنغولي يهودي",
    "jewish argentine history": "تاريخ أرجنتيني يهودي",
    "jewish armenian history": "تاريخ أرميني يهودي",
    "jewish australian history": "تاريخ أسترالي يهودي",
    "jewish austrian history": "تاريخ نمساوي يهودي",
    "jewish azerbaijani history": "تاريخ أذربيجاني يهودي",
    "jewish bangladeshi history": "تاريخ بنغلاديشي يهودي",
    "jewish belarusian history": "تاريخ بيلاروسي يهودي",
    "jewish belgian history": "تاريخ بلجيكي يهودي",
    "jewish bosnian history": "تاريخ بوسني يهودي",
    "jewish brazilian history": "تاريخ برازيلي يهودي",
    "jewish british history": "تاريخ بريطاني يهودي",
    "jewish bulgarian history": "تاريخ بلغاري يهودي",
    "jewish canadian cuisine": "مطبخ كندي يهودي",
    "jewish canadian history": "تاريخ كندي يهودي",
    "jewish canadian literature": "أدب كندي يهودي",
    "jewish cape verdean history": "تاريخ رأس أخضري يهودي",
    "jewish chilean history": "تاريخ تشيلي يهودي",
    "jewish chinese history": "تاريخ صيني يهودي",
    "jewish christian literature": "أدب مسيحي يهودي",
    "jewish croatian history": "تاريخ كرواتي يهودي",
    "jewish cuban history": "تاريخ كوبي يهودي",
    "jewish cypriot history": "تاريخ قبرصي يهودي",
    "jewish czech history": "تاريخ تشيكي يهودي",
    "jewish danish history": "تاريخ دنماركي يهودي",
    "jewish dutch history": "تاريخ هولندي يهودي",
    "jewish egyptian history": "تاريخ مصري يهودي",
    "jewish english history": "تاريخ إنجليزي يهودي",
    "jewish eritrean history": "تاريخ إريتري يهودي",
    "jewish estonian history": "تاريخ إستوني يهودي",
    "jewish ethiopian history": "تاريخ إثيوبي يهودي",
    "jewish finnish history": "تاريخ فنلندي يهودي",
    "jewish french history": "تاريخ فرنسي يهودي",
    "jewish georgian history": "تاريخ جورجي يهودي",
    "jewish gibraltarian history": "تاريخ جبل طارقي يهودي",
    "jewish greek history": "تاريخ يهودي يوناني",
    "jewish guatemalan history": "تاريخ غواتيمالي يهودي",
    "jewish hong kong history": "تاريخ هونغ كونغي يهودي",
    "jewish hungarian history": "تاريخ مجري يهودي",
    "jewish indian history": "تاريخ هندي يهودي",
    "jewish indonesian history": "تاريخ إندونيسي يهودي",
    "jewish iraqi history": "تاريخ عراقي يهودي",
    "jewish irish history": "تاريخ أيرلندي يهودي",
    "jewish italian history": "تاريخ إيطالي يهودي",
    "jewish jamaican history": "تاريخ جامايكي يهودي",
    "jewish japanese history": "تاريخ ياباني يهودي",
    "jewish jordanian history": "تاريخ أردني يهودي",
    "jewish kenyan history": "تاريخ كيني يهودي",
    "jewish kosovan history": "تاريخ كوسوفي يهودي",
    "jewish kurdish history": "تاريخ كردي يهودي",
    "jewish latvian history": "تاريخ لاتفي يهودي",
    "jewish lebanese history": "تاريخ لبناني يهودي",
    "jewish libyan history": "تاريخ ليبي يهودي",
    "jewish lithuanian history": "تاريخ ليتواني يهودي",
    "jewish luxembourgian history": "تاريخ لوكسمبورغي يهودي",
    "jewish macedonian history": "تاريخ مقدوني يهودي",
    "jewish malagasy history": "تاريخ مدغشقري يهودي",
    "jewish mexican history": "تاريخ مكسيكي يهودي",
    "jewish moldovan history": "تاريخ مولدوفي يهودي",
    "jewish moroccan history": "تاريخ مغربي يهودي",
    "jewish nepalese history": "تاريخ نيبالي يهودي",
    "jewish nigerian history": "تاريخ نيجيري يهودي",
    "jewish norwegian history": "تاريخ نرويجي يهودي",
    "jewish pakistani history": "تاريخ باكستاني يهودي",
    "jewish peruvian history": "تاريخ بيروي يهودي",
    "jewish polish history": "تاريخ بولندي يهودي",
    "jewish portuguese history": "تاريخ برتغالي يهودي",
    "jewish romanian history": "تاريخ روماني يهودي",
    "jewish russian history": "تاريخ روسي يهودي",
    "jewish saudiarabian history": "تاريخ سعودي يهودي",
    "jewish scottish history": "تاريخ إسكتلندي يهودي",
    "jewish serbian history": "تاريخ صربي يهودي",
    "jewish slovak history": "تاريخ سلوفاكي يهودي",
    "jewish slovenian history": "تاريخ سلوفيني يهودي",
    "jewish south african history": "تاريخ جنوب إفريقي يهودي",
    "jewish south korean history": "تاريخ كوري جنوبي يهودي",
    "jewish spanish history": "تاريخ إسباني يهودي",
    "jewish sudanese history": "تاريخ سوداني يهودي",
    "jewish surinamese history": "تاريخ سورينامي يهودي",
    "jewish swedish history": "تاريخ سويدي يهودي",
    "jewish swiss history": "تاريخ سويسري يهودي",
    "jewish syrian history": "تاريخ سوري يهودي",
    "jewish tunisian history": "تاريخ تونسي يهودي",
    "jewish turkish history": "تاريخ تركي يهودي",
    "jewish ugandan history": "تاريخ أوغندي يهودي",
    "jewish ukrainian history": "تاريخ أوكراني يهودي",
    "jewish uruguayan history": "تاريخ أوروغوياني يهودي",
    "jewish uzbek history": "تاريخ أوزبكي يهودي",
    "jewish venezuelan history": "تاريخ فنزويلي يهودي",
    "jewish vietnamese history": "تاريخ فيتنامي يهودي",
    "jewish welsh history": "تاريخ ويلزي يهودي",
    "jewish yemeni history": "تاريخ يمني يهودي",
    "jewish zimbabwean history": "تاريخ زيمبابوي يهودي",
    "jewish-afghan history": "تاريخ أفغاني يهودي",
    "kazakhstani jewish descent": "أصل كازاخستاني يهودي",
    "kazakhstani-jewish descent": "أصل كازاخستاني يهودي",
    "kurdish jewish descent": "أصل كردي يهودي",
    "kurdish jewish diaspora": "شتات كردي يهودي",
    "kurdish-jewish descent": "أصل كردي يهودي",
    "kurdish-jewish diaspora": "شتات كردي يهودي",
    "latvian jewish descent": "أصل لاتفي يهودي",
    "latvian jewish diaspora": "شتات لاتفي يهودي",
    "latvian-jewish descent": "أصل لاتفي يهودي",
    "latvian-jewish diaspora": "شتات لاتفي يهودي",
    "lebanese jewish descent": "أصل لبناني يهودي",
    "lebanese jewish diaspora": "شتات لبناني يهودي",
    "lebanese-jewish descent": "أصل لبناني يهودي",
    "lebanese-jewish diaspora": "شتات لبناني يهودي",
    "libyan jewish descent": "أصل ليبي يهودي",
    "libyan jewish diaspora": "شتات ليبي يهودي",
    "libyan-jewish descent": "أصل ليبي يهودي",
    "libyan-jewish diaspora": "شتات ليبي يهودي",
    "lithuanian jewish descent": "أصل ليتواني يهودي",
    "lithuanian jewish diaspora": "شتات ليتواني يهودي",
    "lithuanian-jewish descent": "أصل ليتواني يهودي",
    "lithuanian-jewish diaspora": "شتات ليتواني يهودي",
    "luxembourgian jewish descent": "أصل لوكسمبورغي يهودي",
    "luxembourgian-jewish descent": "أصل لوكسمبورغي يهودي",
    "macedonian jewish descent": "أصل مقدوني يهودي",
    "macedonian-jewish descent": "أصل مقدوني يهودي",
    "mexican jewish descent": "أصل مكسيكي يهودي",
    "mexican-jewish descent": "أصل مكسيكي يهودي",
    "moldovan jewish descent": "أصل مولدوفي يهودي",
    "moldovan jewish diaspora": "شتات مولدوفي يهودي",
    "moldovan-jewish descent": "أصل مولدوفي يهودي",
    "moldovan-jewish diaspora": "شتات مولدوفي يهودي",
    "moroccan jewish descent": "أصل مغربي يهودي",
    "moroccan jewish diaspora": "شتات مغربي يهودي",
    "moroccan-jewish descent": "أصل مغربي يهودي",
    "moroccan-jewish diaspora": "شتات مغربي يهودي",
    "north african jewish descent": "أصل إفريقي شمالي يهودي",
    "north african jewish diaspora": "شتات إفريقي شمالي يهودي",
    "north african-jewish descent": "أصل إفريقي شمالي يهودي",
    "north african-jewish diaspora": "شتات إفريقي شمالي يهودي",
    "north american jewish descent": "أصل أمريكي شمالي يهودي",
    "north american jewish diaspora": "شتات أمريكي شمالي يهودي",
    "north american-jewish descent": "أصل أمريكي شمالي يهودي",
    "north american-jewish diaspora": "شتات أمريكي شمالي يهودي",
    "ottoman jewish descent": "أصل عثماني يهودي",
    "ottoman-jewish descent": "أصل عثماني يهودي",
    "palestinian jewish descent": "أصل فلسطيني يهودي",
    "palestinian-jewish descent": "أصل فلسطيني يهودي",
    "persian jewish cuisine": "مطبخ فارسي يهودي",
    "polish jewish descent": "أصل بولندي يهودي",
    "polish jewish diaspora": "شتات بولندي يهودي",
    "polish-jewish descent": "أصل بولندي يهودي",
    "polish-jewish diaspora": "شتات بولندي يهودي",
    "portuguese jewish descent": "أصل برتغالي يهودي",
    "portuguese jewish diaspora": "شتات برتغالي يهودي",
    "portuguese-jewish descent": "أصل برتغالي يهودي",
    "portuguese-jewish diaspora": "شتات برتغالي يهودي",
    "romanian jewish descent": "أصل روماني يهودي",
    "romanian jewish diaspora": "شتات روماني يهودي",
    "romanian-jewish descent": "أصل روماني يهودي",
    "romanian-jewish diaspora": "شتات روماني يهودي",
    "russian jewish descent": "أصل روسي يهودي",
    "russian jewish diaspora": "شتات روسي يهودي",
    "russian-jewish descent": "أصل روسي يهودي",
    "russian-jewish diaspora": "شتات روسي يهودي",
    "scottish jewish descent": "أصل إسكتلندي يهودي",
    "scottish-jewish descent": "أصل إسكتلندي يهودي",
    "serbian jewish descent": "أصل صربي يهودي",
    "serbian-jewish descent": "أصل صربي يهودي",
    "slovak jewish descent": "أصل سلوفاكي يهودي",
    "slovak jewish diaspora": "شتات سلوفاكي يهودي",
    "slovak-jewish descent": "أصل سلوفاكي يهودي",
    "slovak-jewish diaspora": "شتات سلوفاكي يهودي",
    "south african jewish descent": "أصل جنوب إفريقي يهودي",
    "south african jewish diaspora": "شتات جنوب إفريقي يهودي",
    "south african-jewish descent": "أصل جنوب إفريقي يهودي",
    "south african-jewish diaspora": "شتات جنوب إفريقي يهودي",
    "south american jewish descent": "أصل أمريكي جنوبي يهودي",
    "south american jewish diaspora": "شتات أمريكي جنوبي يهودي",
    "south american-jewish descent": "أصل أمريكي جنوبي يهودي",
    "south american-jewish diaspora": "شتات أمريكي جنوبي يهودي",
    "spanish jewish descent": "أصل إسباني يهودي",
    "spanish jewish diaspora": "شتات إسباني يهودي",
    "spanish-jewish descent": "أصل إسباني يهودي",
    "spanish-jewish diaspora": "شتات إسباني يهودي",
    "surinamese jewish descent": "أصل سورينامي يهودي",
    "surinamese-jewish descent": "أصل سورينامي يهودي",
    "swedish jewish descent": "أصل سويدي يهودي",
    "swedish-jewish descent": "أصل سويدي يهودي",
    "swiss jewish descent": "أصل سويسري يهودي",
    "swiss-jewish descent": "أصل سويسري يهودي",
    "syrian jewish descent": "أصل سوري يهودي",
    "syrian jewish diaspora": "شتات سوري يهودي",
    "syrian-jewish descent": "أصل سوري يهودي",
    "syrian-jewish diaspora": "شتات سوري يهودي",
    "tajikistani jewish descent": "أصل طاجيكي يهودي",
    "tajikistani-jewish descent": "أصل طاجيكي يهودي",
    "tunisian jewish descent": "أصل تونسي يهودي",
    "tunisian jewish diaspora": "شتات تونسي يهودي",
    "tunisian-jewish descent": "أصل تونسي يهودي",
    "tunisian-jewish diaspora": "شتات تونسي يهودي",
    "turkish jewish descent": "أصل تركي يهودي",
    "turkish jewish diaspora": "شتات تركي يهودي",
    "turkish-jewish descent": "أصل تركي يهودي",
    "turkish-jewish diaspora": "شتات تركي يهودي",
    "ukrainian jewish descent": "أصل أوكراني يهودي",
    "ukrainian jewish diaspora": "شتات أوكراني يهودي",
    "ukrainian-jewish descent": "أصل أوكراني يهودي",
    "ukrainian-jewish diaspora": "شتات أوكراني يهودي",
    "uruguayan jewish descent": "أصل أوروغوياني يهودي",
    "uruguayan-jewish descent": "أصل أوروغوياني يهودي",
    "uzbekistani jewish descent": "أصل أوزبكستاني يهودي",
    "uzbekistani-jewish descent": "أصل أوزبكستاني يهودي",
    "venezuelan jewish descent": "أصل فنزويلي يهودي",
    "venezuelan-jewish descent": "أصل فنزويلي يهودي",
    "welsh jewish descent": "أصل ويلزي يهودي",
    "welsh-jewish descent": "أصل ويلزي يهودي",
    "yemeni jewish descent": "أصل يمني يهودي",
    "yemeni jewish diaspora": "شتات يمني يهودي",
    "yemeni-jewish descent": "أصل يمني يهودي",
    "yemeni-jewish diaspora": "شتات يمني يهودي",
}

males_tests = {
    "austrian nazis": "نازيون نمساويون",
    "british antigua and barbuda": "أنتيغويون وبربوديون بريطانيون",
    "european american": "أمريكيون أوروبيون",
    "ivorian american": "أمريكيون إيفواريون",
    "japanese americans": "أمريكيون يابانيون",
    "jewish americans": "أمريكيون يهود",
    "jewish persian": "فرس يهود",
    "jewish russian": "روس يهود",
    "luxembourgian european": "أوروبيون لوكسمبورغيون",
    "romanian european": "أوروبيون رومان",
    "sri lankan english": "إنجليز سريلانكيون",
    "venezuelan spanish": "إسبان فنزويليون",
    "yemeni yugoslav": "يمنيون يوغسلافيون",
    "yemeni-yugoslav": "يمنيون يوغسلافيون",
}

female_tests = {
    "chinese australian culture": "ثقافة أسترالية صينية",
    "danish american culture": "ثقافة أمريكية دنماركية",
    "european american culture": "ثقافة أمريكية أوروبية",
    "european argentine culture": "ثقافة أرجنتينية أوروبية",
    "korean american culture": "ثقافة أمريكية كورية",
    "lebanese canadian culture": "ثقافة كندية لبنانية",
    "african jewish culture": "ثقافة إفريقية يهودية",
    "african-jewish culture": "ثقافة إفريقية يهودية",
    "algerian jewish culture": "ثقافة جزائرية يهودية",
    "algerian-jewish culture": "ثقافة جزائرية يهودية",
    "american jewish culture": "ثقافة أمريكية يهودية",
    "american-jewish culture": "ثقافة أمريكية يهودية",
    "arab jewish culture": "ثقافة عربية يهودية",
    "arab jewish surnames": "ألقاب عربية يهودية",
    "arab-jewish culture": "ثقافة عربية يهودية",
    "arab-jewish surnames": "ألقاب عربية يهودية",
    "argentine jewish culture": "ثقافة أرجنتينية يهودية",
    "argentine-jewish culture": "ثقافة أرجنتينية يهودية",
    "asian jewish culture": "ثقافة آسيوية يهودية",
    "asian-jewish culture": "ثقافة آسيوية يهودية",
    "australian jewish culture": "ثقافة أسترالية يهودية",
    "australian-jewish culture": "ثقافة أسترالية يهودية",
    "austrian jewish culture": "ثقافة نمساوية يهودية",
    "austrian-jewish culture": "ثقافة نمساوية يهودية",
    "belarusian jewish culture": "ثقافة بيلاروسية يهودية",
    "belarusian-jewish culture": "ثقافة بيلاروسية يهودية",
    "british jewish culture": "ثقافة بريطانية يهودية",
    "british-jewish culture": "ثقافة بريطانية يهودية",
    "bulgarian jewish culture": "ثقافة بلغارية يهودية",
    "bulgarian-jewish culture": "ثقافة بلغارية يهودية",
    "canadian jewish culture": "ثقافة كندية يهودية",
    "canadian-jewish culture": "ثقافة كندية يهودية",
    "czech jewish culture": "ثقافة تشيكية يهودية",
    "czech-jewish culture": "ثقافة تشيكية يهودية",
    "dutch jewish culture": "ثقافة هولندية يهودية",
    "dutch-jewish culture": "ثقافة هولندية يهودية",
    "egyptian jewish culture": "ثقافة مصرية يهودية",
    "egyptian-jewish culture": "ثقافة مصرية يهودية",
    "english jewish culture": "ثقافة إنجليزية يهودية",
    "english-jewish culture": "ثقافة إنجليزية يهودية",
    "ethiopian jewish culture": "ثقافة إثيوبية يهودية",
    "ethiopian-jewish culture": "ثقافة إثيوبية يهودية",
    "european jewish culture": "ثقافة أوروبية يهودية",
    "european-jewish culture": "ثقافة أوروبية يهودية",
    "french jewish culture": "ثقافة فرنسية يهودية",
    "french-jewish culture": "ثقافة فرنسية يهودية",
    "georgian jewish culture": "ثقافة جورجية يهودية",
    "georgian-jewish culture": "ثقافة جورجية يهودية",
    "german jewish culture": "ثقافة ألمانية يهودية",
    "german-jewish culture": "ثقافة ألمانية يهودية",
    "greek jewish culture": "ثقافة يهودية يونانية",
    "greek-jewish culture": "ثقافة يهودية يونانية",
    "hungarian jewish culture": "ثقافة مجرية يهودية",
    "hungarian-jewish culture": "ثقافة مجرية يهودية",
    "indian jewish culture": "ثقافة هندية يهودية",
    "indian-jewish culture": "ثقافة هندية يهودية",
    "iranian jewish culture": "ثقافة إيرانية يهودية",
    "iranian-jewish culture": "ثقافة إيرانية يهودية",
    "iraqi jewish culture": "ثقافة عراقية يهودية",
    "iraqi-jewish culture": "ثقافة عراقية يهودية",
    "italian jewish culture": "ثقافة إيطالية يهودية",
    "italian-jewish culture": "ثقافة إيطالية يهودية",
    "jewish argentine culture": "ثقافة أرجنتينية يهودية",
    "jewish austrian families": "عائلات نمساوية يهودية",
    "jewish british culture": "ثقافة بريطانية يهودية",
    "jewish british families": "عائلات بريطانية يهودية",
    "jewish canadian culture": "ثقافة كندية يهودية",
    "jewish canadian families": "عائلات كندية يهودية",
    "jewish canadian television series": "مسلسلات تلفزيونية كندية يهودية",
    "jewish chinese families": "عائلات صينية يهودية",
    "jewish danish families": "عائلات دنماركية يهودية",
    "jewish french culture": "ثقافة فرنسية يهودية",
    "jewish french families": "عائلات فرنسية يهودية",
    "jewish german culture": "ثقافة ألمانية يهودية",
    "jewish german families": "عائلات ألمانية يهودية",
    "jewish hungarian families": "عائلات مجرية يهودية",
    "jewish israeli culture": "ثقافة إسرائيلية يهودية",
    "jewish italian families": "عائلات إيطالية يهودية",
    "jewish polish families": "عائلات بولندية يهودية",
    "jewish portuguese families": "عائلات برتغالية يهودية",
    "jewish south african families": "عائلات جنوب إفريقية يهودية",
    "jewish-austrian families": "عائلات نمساوية يهودية",
    "jewish-british families": "عائلات بريطانية يهودية",
    "jewish-canadian families": "عائلات كندية يهودية",
    "jewish-chinese families": "عائلات صينية يهودية",
    "jewish-danish families": "عائلات دنماركية يهودية",
    "jewish-french families": "عائلات فرنسية يهودية",
    "jewish-german families": "عائلات ألمانية يهودية",
    "jewish-hungarian families": "عائلات مجرية يهودية",
    "jewish-italian families": "عائلات إيطالية يهودية",
    "jewish-polish families": "عائلات بولندية يهودية",
    "jewish-portuguese families": "عائلات برتغالية يهودية",
    "jewish-south african families": "عائلات جنوب إفريقية يهودية",
    "kurdish jewish culture": "ثقافة كردية يهودية",
    "kurdish-jewish culture": "ثقافة كردية يهودية",
    "latvian jewish culture": "ثقافة لاتفية يهودية",
    "latvian-jewish culture": "ثقافة لاتفية يهودية",
    "libyan jewish culture": "ثقافة ليبية يهودية",
    "libyan-jewish culture": "ثقافة ليبية يهودية",
    "lithuanian jewish culture": "ثقافة ليتوانية يهودية",
    "lithuanian-jewish culture": "ثقافة ليتوانية يهودية",
    "moroccan jewish culture": "ثقافة مغربية يهودية",
    "moroccan-jewish culture": "ثقافة مغربية يهودية",
    "north african jewish culture": "ثقافة إفريقية شمالية يهودية",
    "north african-jewish culture": "ثقافة إفريقية شمالية يهودية",
    "north american jewish culture": "ثقافة أمريكية شمالية يهودية",
    "north american-jewish culture": "ثقافة أمريكية شمالية يهودية",
    "polish jewish culture": "ثقافة بولندية يهودية",
    "polish-jewish culture": "ثقافة بولندية يهودية",
    "portuguese jewish culture": "ثقافة برتغالية يهودية",
    "portuguese-jewish culture": "ثقافة برتغالية يهودية",
    "romanian jewish culture": "ثقافة رومانية يهودية",
    "romanian-jewish culture": "ثقافة رومانية يهودية",
    "russian jewish culture": "ثقافة روسية يهودية",
    "russian jewish surnames": "ألقاب روسية يهودية",
    "russian-jewish culture": "ثقافة روسية يهودية",
    "russian-jewish surnames": "ألقاب روسية يهودية",
    "slovak jewish culture": "ثقافة سلوفاكية يهودية",
    "slovak-jewish culture": "ثقافة سلوفاكية يهودية",
    "south african jewish culture": "ثقافة جنوب إفريقية يهودية",
    "south african-jewish culture": "ثقافة جنوب إفريقية يهودية",
    "south american jewish culture": "ثقافة أمريكية جنوبية يهودية",
    "south american-jewish culture": "ثقافة أمريكية جنوبية يهودية",
    "spanish jewish culture": "ثقافة إسبانية يهودية",
    "spanish-jewish culture": "ثقافة إسبانية يهودية",
    "syrian jewish culture": "ثقافة سورية يهودية",
    "syrian-jewish culture": "ثقافة سورية يهودية",
    "tunisian jewish culture": "ثقافة تونسية يهودية",
    "tunisian-jewish culture": "ثقافة تونسية يهودية",
    "turkish jewish culture": "ثقافة تركية يهودية",
    "turkish-jewish culture": "ثقافة تركية يهودية",
    "ukrainian jewish culture": "ثقافة أوكرانية يهودية",
    "ukrainian-jewish culture": "ثقافة أوكرانية يهودية",
    "yemeni jewish culture": "ثقافة يمنية يهودية",
    "yemeni-jewish culture": "ثقافة يمنية يهودية",
    "yugoslav jewish culture": "ثقافة يهودية يوغسلافية",
    "yugoslav-jewish culture": "ثقافة يهودية يوغسلافية",
}

test_data_fast = {
    "american christian musical groups": "فرق موسيقية أمريكية مسيحية",
    "australian christian musical groups": "فرق موسيقية أسترالية مسيحية",
    "british christian musical groups": "فرق موسيقية بريطانية مسيحية",
    "canadian christian musical groups": "فرق موسيقية كندية مسيحية",
    "swedish christian musical groups": "فرق موسيقية سويدية مسيحية",
    "english christian musical groups": "فرق موسيقية إنجليزية مسيحية",
    "finnish christian musical groups": "فرق موسيقية فنلندية مسيحية",
    "brazilian christian music": "موسيقى برازيلية مسيحية",
    "democratic republic of congo christian music": "موسيقى كونغوية ديمقراطية مسيحية",
    "ghanaian christian music": "موسيقى غانية مسيحية",
    "rwandan christian music": "موسيقى رواندية مسيحية",
    "american christian novels": "روايات أمريكية مسيحية",
    "english gothic architecture": "عمارة إنجليزية قوطية",
    "turkish kurdish people": "أتراك أكراد",
    "norwegian christian musical groups": "فرق موسيقية مسيحية نرويجية",
    "dutch christian music": "موسيقى مسيحية هولندية",
    "indian christian music": "موسيقى مسيحية هندية",
    "irish american gangs": "عصابات أمريكية أيرلندية",
    "british antigua and barbuda people": "أنتيغويون وبربوديون بريطانيون",
}


@pytest.mark.parametrize("category, expected_key", male_tests.items(), ids=male_tests.keys())
@pytest.mark.fast
def test_male_tests(category: str, expected_key: str) -> None:
    label2 = resolve_by_nats_double_v2(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", males_tests.items(), ids=males_tests.keys())
@pytest.mark.fast
def test_males_tests(category: str, expected_key: str) -> None:
    label2 = resolve_by_nats_double_v2(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", female_tests.items(), ids=female_tests.keys())
@pytest.mark.fast
def test_female_tests(category: str, expected_key: str) -> None:
    label2 = resolve_by_nats_double_v2(category)
    assert label2 == expected_key


to_test = [
    ("test_male_tests", male_tests, resolve_by_nats_double_v2),
    ("test_males_tests", males_tests, resolve_by_nats_double_v2),
    ("test_female_tests", female_tests, resolve_by_nats_double_v2),
    ("test_data_fast", test_data_fast, resolve_by_nats_double_v2),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_non_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""

This module provides functionality to translate category titles
that follow a 'nat-year' pattern. It uses a pre-configured
bot (`yc_bot`) to handle the translation logic.
    "2000s American films": "أفلام أمريكية في عقد 2000",
"""

import functools

from ...helps import logger
from ...translations import all_country_with_nat_ar
from ...translations_formats import (
    MultiDataFormatterBaseYearV2,
    format_year_country_data_v2,
)

# from ..main_processers.categories_patterns.COUNTRY_YEAR import COUNTRY_YEAR_DATA
formatted_data = {
    # "12th-century Indian books": "كتب هندية في القرن 12",
    "{year1} {en_nat} books": "كتب {female} في {year1}",
    # "20th-century Mexican literature": "أدب مكسيكي القرن 20",
    "{year1} {en_nat} literature": "أدب {male} في {year1}",
    # "coming-of-age story television programmes endings": "برامج تلفزيونية قصة تقدم في العمر انتهت في",
    "{year1} {en_nat} coming-of-age story television programmes endings": "برامج تلفزيونية قصة تقدم في العمر انتهت في {year1}",
    "{year1} {en_nat} films": "أفلام {female} في {year1}",
    "{year1} {en_nat} texts": "نصوص {female} في {year1}",
    "{en_nat} general election {year1}": "الانتخابات التشريعية {the_female} {year1}",
    "{en_nat} presidential election {year1}": "انتخابات الرئاسة {the_female} {year1}",
}


def populate_film_patterns(formatted_data):
    """
    Add Arabic translations for specific film-related category patterns into the provided formatted_data mapping.

    Updates formatted_data in-place with entries for base, year-prefixed, nat-prefixed, and "-endings"/" endings" variants for two film-related titles ("animated television series" and "children's animated adventure television series"), using both plain and gendered (`{female}`) value forms and year/placeholders (`{year1}`, `{en_nat}`).

    Parameters:
        formatted_data (dict): Mapping of pattern keys to translation strings; the function mutates this dict by inserting the generated patterns.
    """
    films_non_patterns_data = {
        "animated television series": {
            "value": "مسلسلات رسوم متحركة تلفزيونية",
            "value_nat": "مسلسلات رسوم متحركة تلفزيونية {female}",
        },
        "children's animated adventure television series": {
            "value": "مسلسلات مغامرات رسوم متحركة تلفزيونية للأطفال",
            "value_nat": "مسلسلات مغامرات رسوم متحركة تلفزيونية {female} للأطفال",
        },
    }
    for k, v in films_non_patterns_data.items():
        value_with_nat = v.get("value_nat")
        value = v.get("value")
        formatted_data.update(
            {
                f"{k}": f"{value}",
                f"{{year1}} {k}": f"{value} في {{year1}}",
                f"{{en_nat}} {k}": f"{value_with_nat}",
                f"{{year1}} {{en_nat}} {k}": f"{value_with_nat} في {{year1}}",
                f"{{year1}} {k}-endings": f"{value} انتهت في {{year1}}",
                f"{{year1}} {k} endings": f"{value} انتهت في {{year1}}",
                f"{{year1}} {{en_nat}} {k}-endings": f"{value_with_nat} انتهت في {{year1}}",
                f"{{year1}} {{en_nat}} {k} endings": f"{value_with_nat} انتهت في {{year1}}",
            }
        )


@functools.lru_cache(maxsize=1)
def _bot_new() -> MultiDataFormatterBaseYearV2:
    """
    Constructs and returns a MultiDataFormatterBaseYearV2 configured with nat-year translation patterns.

    Initializes the formatter with predefined pattern mappings and the available Arabic nationality data so it can expand category templates containing the placeholders `{en_nat}` and `{year1}` into Arabic nat-year phrases.

    Returns:
        MultiDataFormatterBaseYearV2: A formatter set up to format categories that combine nationality and year placeholders into Arabic translations.
    """
    # populate_film_patterns(formatted_data)

    nats_data = {x: v for x, v in all_country_with_nat_ar.items() if v.get("ar")}

    return format_year_country_data_v2(
        formatted_data=formatted_data,
        data_list=nats_data,
        key_placeholder="{en_nat}",
        key2_placeholder="{year1}",
        value2_placeholder="{year1}",
        text_after="",
        text_before="the ",
    )


@functools.lru_cache(maxsize=10000)
def resolve_nats_time_v2(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_nats_time_v2: {category=}")
    yc_bot = _bot_new()

    result = yc_bot.search_all_category(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_nats_time_v2: {category=}, {result=}", result)
    return result or ""


__all__ = [
    "resolve_nats_time_v2",
]



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar

data_fast = {
    "bulgarian cup": "كأس بلغاريا",
    "swiss grand prix": "جائزة سويسرا الكبرى",
    "Anglican archbishops of Papua New Guinea": "رؤساء أساقفة أنجليكيون في بابوا غينيا الجديدة",
    "shi'a muslims expatriates": "مسلمون شيعة مغتربون",
    "african people by nationality": "أفارقة حسب الجنسية",
    "andy warhol": "آندي وارهول",
    "caymanian expatriates": "كايمانيون مغتربون",
    "eddie murphy": "إيدي ميرفي",
    "english-language culture": "ثقافة اللغة الإنجليزية",
    "english-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإنجليزية",
    "english-language radio stations": "محطات إذاعية باللغة الإنجليزية",
    "fijian language": "لغة فيجية",
    "francisco goya": "فرانثيسكو غويا",
    "french-language albums": "ألبومات باللغة الفرنسية",
    "french-language television": "تلفاز باللغة الفرنسية",
    "german people by occupation": "ألمان حسب المهنة",
    "german-language films": "أفلام باللغة الألمانية",
    "idina menzel": "إيدينا مينزيل",
    "igor stravinsky": "إيغور سترافينسكي",
    "japanese language": "لغة يابانية",
    "johann wolfgang von goethe": "يوهان فولفغانغ فون غوته",
    "lithuanian men's footballers": "لاعبو كرة قدم ليتوانيون",
    "marathi films": "أفلام باللغة الماراثية",
    "michael porter": "مايكل بورتر",
    "polish-language films": "أفلام باللغة البولندية",
    "sara bareilles": "سارة باريلز",
    "spanish-language mass media": "إعلام اللغة الإسبانية",
    "surinamese women children's writers": "كاتبات أطفال سوريناميات",
    "swedish-language albums": "ألبومات باللغة السويدية",
}


@pytest.mark.parametrize("category, expected_key", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_data_fast(category: str, expected_key: str) -> None:
    label1 = resolve_label_ar(category)
    assert label1 == expected_key


to_test = [
    ("te4_2018_data_fast", data_fast),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)

    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
# isort:skip_file
"""

from __future__ import annotations

import functools
from dataclasses import dataclass
import re
from ..helps import logger
from ..patterns_resolvers import nat_men_pattern
from ..legacy_bots import with_years_bot
from ..legacy_bots.o_bots import univer
from ..legacy_bots.ma_bots.country_bot import event2_d2
from . import event_lab_bot
from ..time_resolvers.labs_years import LabsYears
from ..patterns_resolvers.country_time_pattern import resolve_country_time_pattern
from ..legacy_bots.ma_bots2.year_or_typeo import label_for_startwith_year_or_typeo
from ..config import app_settings
from ..legacy_bots.make_bots import filter_en
from ..format_bots import change_cat
from ..legacy_bots.ma_bots import ye_ts_bot
from ..legacy_bots.matables_bots.bot import cash_2022
from ..new_resolvers.reslove_all import new_resolvers_all
from ..fix import fixlabel


@dataclass
class CategoryResult:
    """Data structure representing each processed category."""

    en: str
    ar: str
    from_match: str


@functools.lru_cache(maxsize=1)
def build_labs_years_object() -> LabsYears:
    return LabsYears()


def retrieve_year_from_category(category):
    logger.debug(f"<<yellow>> start lab_from_year: {category=}")

    labs_years_bot = build_labs_years_object()
    cat_year, from_year = labs_years_bot.lab_from_year(category)

    logger.info_if_or_debug(f"<<yellow>> end lab_from_year: {category=}, {from_year=}", from_year)
    return cat_year, from_year


@functools.lru_cache(maxsize=None)
def resolve_label(category: str, fix_label: bool = True) -> CategoryResult:
    """Resolve the label using multi-step logic."""
    changed_cat = change_cat(category)

    if category.isdigit():
        return CategoryResult(
            en=category,
            ar=category,
            from_match=False,
        )

    if changed_cat.isdigit():
        return CategoryResult(
            en=category,
            ar=changed_cat,
            from_match=False,
        )

    is_cat_okay = filter_en.filter_cat(category)

    category_lab = ""

    cat_year, from_year = retrieve_year_from_category(category)

    if from_year:
        category_lab = from_year

    if not category_lab:
        category_lab = (
            # NOTE: resolve_nat_genders_pattern_v2 IN TESTING HERE ONLY
            # resolve_nat_genders_pattern_v2(changed_cat) or
            new_resolvers_all(changed_cat)
            or ""
        )

    start_ylab = ""
    from_match = False
    if not category_lab:
        category_lab = resolve_country_time_pattern(changed_cat)  # or resolve_nat_women_time_pattern(changed_cat)
        from_match = category_lab != ""

    if not category_lab:
        category_lab = nat_men_pattern.resolve_nat_men_pattern_new(changed_cat)
        from_match = category_lab != ""

    start_ylab = ""
    # if not category_lab: start_ylab = ye_ts_bot.translate_general_category(changed_cat)

    if not category_lab and is_cat_okay:
        category_lower = category.lower()
        if category_lower != changed_cat:
            category_lab = cash_2022.get(category_lower, "")
        if not category_lab:
            category_lab = cash_2022.get(changed_cat, "")

        if not category_lab and app_settings.start_tgc_resolver_first:
            category_lab = start_ylab

        if not category_lab:
            category_lab = (
                univer.te_universities(changed_cat)
                or event2_d2(changed_cat)
                or with_years_bot.Try_With_Years2(changed_cat)
                or label_for_startwith_year_or_typeo(changed_cat)
                or ""
            )

        if not category_lab:
            category_lab = event_lab_bot.event_Lab(changed_cat)

    if not category_lab and is_cat_okay:
        # category_lab = start_ylab
        category_lab = ye_ts_bot.translate_general_category(changed_cat)

    if category_lab and fix_label:
        category_lab = fixlabel(category_lab, en=category)

    # NOTE: causing some issues with years and decades
    # [Category:1930s Japanese novels] : "تصنيف:روايات يابانية في عقد 1930",
    # [Category:1930s Japanese novels] : "تصنيف:روايات يابانية في عقد 1930",

    # if not from_year and cat_year:
    # labs_years_bot.lab_from_year_add(category, category_lab, en_year=cat_year)

    category_lab = re.sub(r"سانتا-في", "سانتا في", category_lab)

    return CategoryResult(
        en=category,
        ar=category_lab,
        from_match=cat_year or from_match,
    )


def resolve_label_ar(category: str, fix_label: bool = True) -> str:
    """Resolve the Arabic label for a given category."""
    result = resolve_label(category, fix_label=fix_label)
    return result.ar


__all__ = [
    "resolve_label",
    "resolve_label_ar",
]



"""
TODO: use mens_resolver_labels
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.jobs_resolvers.mens import mens_resolver_labels

test_mens_data = {
    "ancient romans killed in action": "رومان قدماء قتلوا في عمليات قتالية",
    "bulgarian deaf": "بلغاريون صم",
    "czech deaf": "تشيكيون صم",
    "expatriate academics": "أكاديميون مغتربون",
    "expatriate actors": "ممثلون مغتربون",
    "expatriate artists": "فنانون مغتربون",
    "expatriate baseball players": "لاعبو كرة قاعدة مغتربون",
    "expatriate bishops": "أساقفة مغتربون",
    "expatriate cricketers": "لاعبو كريكت مغتربون",
    "expatriate dancers": "راقصون مغتربون",
    "expatriate field hockey players": "لاعبو هوكي ميدان مغتربون",
    "expatriate football managers": "مدربو كرة قدم مغتربون",
    "expatriate footballers": "لاعبو كرة قدم مغتربون",
    "expatriate futsal players": "لاعبو كرة صالات مغتربون",
    "expatriate golfers": "لاعبو غولف مغتربون",
    "expatriate handball players": "لاعبو كرة يد مغتربون",
    "expatriate ice hockey players": "لاعبو هوكي جليد مغتربون",
    "expatriate rugby league players": "لاعبو دوري رجبي مغتربون",
    "expatriate rugby union players": "لاعبو اتحاد رجبي مغتربون",
    "expatriate soccer players": "لاعبو كرة قدم مغتربون",
    "expatriate swimmers": "سباحون مغتربون",
    "expatriate tennis players": "لاعبو كرة مضرب مغتربون",
    "expatriate volleyball players": "لاعبو كرة طائرة مغتربون",
    "hungarian blind": "مجريون مكفوفون",
    "liberian blind": "ليبيريون مكفوفون",
    "malagasy people murdered abroad": "مدغشقريون قتلوا في الخارج",
    "mercenaries killed in action": "مرتزقة قتلوا في عمليات قتالية",
    "military personnel killed-in-action": "أفراد عسكريون قتلوا في عمليات قتالية",
    "russian blind": "روس مكفوفون",
    "singaporean blind": "سنغافوريون مكفوفون",
    "slovenian deaf": "سلوفينيون صم",
    "sri lankan deaf": "سريلانكيون صم",
    "taiwanese blind": "تايوانيون مكفوفون",
    "ukrainian deaf": "أوكرانيون صم",
    "uruguayan deaf": "أوروغويانيون صم",
}

test_mens_data2 = {
    "men athletes": "لاعبو قوى",
    "men centenarians": "مئويون",
    "men competitors": "منافسون",
    "men discus throwers": "رماة قرص",
    "men hammer throwers": "رماة مطرقة",
    "men high jumpers": "متسابقو قفز عالي",
    "men hurdlers": "لاعبو قفز الحواجز",
    "men long jumpers": "لاعبو قفز طويل",
    "men long-distance runners": "عداؤو مسافات طويلة",
    "men marathon runners": "عداؤو ماراثون",
    "men middle-distance runners": "عداؤو مسافات متوسطة",
    "men pole vaulters": "قافزون بالزانة",
    "men runners": "عداؤون",
    "men shot putters": "لاعبو دفع ثقل",
    "men sprinters": "عداؤون سريعون",
    "men steeplechase runners": "عداؤو موانع",
    "men triple jumpers": "لاعبو وثب ثلاثي",
    "men wheelchair racers": "متسابقو كراسي متحركة",
    "fictional firefighters": "رجال إطفاء خياليون",
    "fictional australian rules footballers": "لاعبو كرة قدم أسترالية خياليون",
    "assassinated civil rights activists": "ناشطو حقوق مدنية مغتالون",
    "assassinated ecuadorian people": "إكوادوريون مغتالون",
    "assassinated educators": "معلمون مغتالون",
    "assassinated english people": "إنجليز مغتالون",
    "assassinated journalists": "صحفيون مغتالون",
    "assassinated kenyan people": "كينيون مغتالون",
    "assassinated latvian people": "لاتفيون مغتالون",
    "assassinated liberian people": "ليبيريون مغتالون",
    "assassinated monarchs": "ملكيون مغتالون",
    "assassinated monegasque people": "موناكيون مغتالون",
    "assassinated newspaper editors": "محررو صحف مغتالون",
    "assassinated politicians": "سياسيون مغتالون",
    "assassinated radio people": "أعلام راديو مغتالون",
    "assassinated spanish people": "إسبان مغتالون",
    "blind blues musicians": "موسيقيو بلوز مكفوفون",
    "blind harmonica players": "لاعبو هارمونيكا مكفوفون",
    "blind musicians": "موسيقيون مكفوفون",
    "blind writers": "كتاب مكفوفون",
    "child actors": "ممثلون أطفال",
    "child jazz musicians": "موسيقيو جاز أطفال",
    "child singers": "مغنون أطفال",
    "child writers": "كتاب أطفال",
    "contemporary artists": "فنانون معاصرون",
    "contemporary painters": "رسامون معاصرون",
    "contemporary philosophers": "فلاسفة معاصرون",
    "contemporary sculptors": "نحاتون معاصرون",
    "deaf baseball players": "لاعبو كرة قاعدة صم",
    "deaf poets": "شعراء صم",
    "deaf sports-people": "رياضيون صم",
    "deaf television presenters": "مذيعو تلفزيون صم",
    "deaf triathletes": "لاعبو ترياثلون صم",
    "disabled sports-people": "رياضيون معاقون",
    "fictional american people": "أمريكيون خياليون",
    "fictional armenian people": "أرمن خياليون",
    "fictional barons": "بارونات خياليون",
    "fictional british people": "بريطانيون خياليون",
    "fictional burmese people": "بورميون خياليون",
    "fictional businesspeople": "شخصيات أعمال خياليون",
    "fictional catholics": "كاثوليك خياليون",
    "fictional civil servants": "موظفو خدمة مدنية خياليون",
    "fictional diarists": "كتاب يوميات خياليون",
    "fictional engineers": "مهندسون خياليون",
    "fictional entertainers": "فنانون ترفيهيون خياليون",
    "fictional herpetologists": "علماء زواحف وبرمائيات خياليون",
    "fictional indian people": "هنود خياليون",
    "fictional murderers": "قتلة خياليون",
    "fictional pakistani people": "باكستانيون خياليون",
    "fictional politicians": "سياسيون خياليون",
    "fictional psychics": "وسطاء خياليون",
    "fictional salvadoran people": "سلفادوريون خياليون",
    "fictional scientists": "علماء خياليون",
    "fictional sheriffs": "مأمورون خياليون",
    "fictional southeast asian people": "آسيويون جنوبيون شرقيون خياليون",
    "fictional tajikistani people": "طاجيك خياليون",
    "kidnapped american people": "أمريكيون مختطفون",
    "kidnapped chinese people": "صينيون مختطفون",
    "kidnapped politicians": "سياسيون مختطفون",
    "kidnapped sri lankan people": "سريلانكيون مختطفون",
    "latin american people": "أمريكيون لاتينيون",
    "latin dance singers": "مغنو رقص لاتينيون",
    "latin jazz pianists": "عازفو بيانو جاز لاتينيون",
    "military aviators": "طيارون عسكريون",
    "military doctors": "أطباء عسكريون",
    "military governors": "حكام عسكريون",
    "military snipers": "قناصون عسكريون",
    "political artists": "فنانون سياسيون",
    "political consultants": "استشاريون سياسيون",
    "political prisoners": "مسجونون سياسيون",
    "political sociologists": "علماء اجتماع سياسيون",
    "religious philosophers": "فلاسفة دينيون",
    "religious workers": "عمال دينيون",
    "religious writers": "كتاب دينيون",
}

test_mens_data_male = {
    "expatriate male actors": "ممثلون ذكور مغتربون",
    "male actors": "ممثلون ذكور",
    "male alpine skiers": "متزحلقو منحدرات ثلجية ذكور",
    "male archers": "نبالون ذكور",
    "male artistic gymnasts": "لاعبو جمباز فني ذكور",
    "male artists": "فنانون ذكور",
    "male athletes": "لاعبو قوى ذكور",
    "male badminton players": "لاعبو تنس ريشة ذكور",
    "male ballet dancers": "راقصو باليه ذكور",
    "male biathletes": "لاعبو بياثلون ذكور",
    "male bloggers": "مدونون ذكور",
    "male bobsledders": "متزلجون جماعيون ذكور",
    "male boxers": "ملاكمون ذكور",
    "male canoeists": "متسابقو قوارب الكانوي ذكور",
    "male classical composers": "ملحنون كلاسيكيون ذكور",
    "male classical pianists": "عازفو بيانو كلاسيكيون ذكور",
    "male comedians": "كوميديون ذكور",
    "male composers": "ملحنون ذكور",
    "male conductors (music)": "قادة فرق موسيقية ذكور",
    "male critics": "نقاد ذكور",
    "male cross-country skiers": "متزحلقون ريفيون ذكور",
    "male cyclists": "دراجون ذكور",
    "male dancers": "راقصون ذكور",
    "male divers": "غواصون ذكور",
    "male dramatists and playwrights": "كتاب دراما ومسرح ذكور",
    "male dramatists": "دراميون ذكور",
    "male entertainers": "فنانون ترفيهيون ذكور",
    "male equestrians": "فرسان خيول ذكور",
    "male essayists": "كتاب مقالات ذكور",
    "male fencers": "مبارزون ذكور",
    "male field hockey defenders": "مدافعو هوكي ميدان ذكور",
    "male field hockey players": "لاعبو هوكي ميدان ذكور",
    "male figure skaters": "متزلجون فنيون ذكور",
    "male film actors": "ممثلو أفلام ذكور",
    "male folk singers": "مغنو فولك ذكور",
    "male freestyle skiers": "ممارسو تزلج حر ذكور",
    "male freestyle swimmers": "سباحو تزلج حر ذكور",
    "male golfers": "لاعبو غولف ذكور",
    "male guitarists": "عازفو قيثارة ذكور",
    "male ice dancers": "راقصو جليد ذكور",
    "male jazz musicians": "موسيقيو جاز ذكور",
    "male journalists": "صحفيون ذكور",
    "male judoka": "لاعبو جودو ذكور",
    "male kabaddi players": "لاعبو كابادي ذكور",
    "male karateka": "ممارسو كاراتيه ذكور",
    "male kickboxers": "مقاتلو كيك بوكسنغ ذكور",
    "male long-distance runners": "عداؤو مسافات طويلة ذكور",
    "male lugers": "زاحفون ثلجيون ذكور",
    "male mandolinists": "عازفو مندولين ذكور",
    "male martial artists": "ممارسو فنون قتالية ذكور",
    "male middle-distance runners": "عداؤو مسافات متوسطة ذكور",
    "male mixed martial artists": "مقاتلو فنون قتالية مختلطة ذكور",
    "male models": "عارضو أزياء ذكور",
    "male modern pentathletes": "متسابقو خماسي حديث ذكور",
    "male muay thai practitioners": "ممارسو موياي تاي ذكور",
    "male musical theatre actors": "ممثلو مسرحيات موسيقية ذكور",
    "male musicians": "موسيقيون ذكور",
    "male non-fiction writers": "كتاب غير روائيين ذكور",
    "male nordic combined skiers": "متزحلقو تزلج نوردي مزدوج ذكور",
    "male novelists": "روائيون ذكور",
    "male opera composers": "ملحنو أوبرا ذكور",
    "male opera singers": "مغنو أوبرا ذكور",
    "male painters": "رسامون ذكور",
    "male pair skaters": "متزلجون فنيون على الجليد ذكور",
    "male photographers": "مصورون ذكور",
    "male pianists": "عازفو بيانو ذكور",
    "male poets": "شعراء ذكور",
    "male pop singers": "مغنو بوب ذكور",
    "male pornographic film actors": "ممثلو أفلام إباحية ذكور",
    "male professional wrestlers": "مصارعون محترفون ذكور",
    "male radio actors": "ممثلو راديو ذكور",
    "male rappers": "مغنو راب ذكور",
    "male rowers": "مجدفون ذكور",
    "male runners": "عداؤون ذكور",
    "male sailors (sport)": "بحارة رياضيون ذكور",
    "male screenwriters": "كتاب سيناريو ذكور",
    "male short story writers": "كتاب قصة قصيرة ذكور",
    "male silent film actors": "ممثلو أفلام صامتة ذكور",
    "male singer-songwriters": "مغنون وكتاب أغاني ذكور",
    "male singers": "مغنون ذكور",
    "male single skaters": "متزلجون فرديون ذكور",
    "male skeleton racers": "متزلجون صدريون ذكور",
    "male ski jumpers": "متزلجو قفز ذكور",
    "male skiers": "متزحلقون ذكور",
    "male snowboarders": "متزلجون على الثلج ذكور",
    "male soap opera actors": "ممثلو مسلسلات طويلة ذكور",
    "male songwriters": "كتاب أغان ذكور",
    "male speed skaters": "متزلجو سرعة ذكور",
    "male sport shooters": "لاعبو رماية ذكور",
    "male sport wrestlers": "مصارعون رياضيون ذكور",
    "male stage actors": "ممثلو مسرح ذكور",
    "male steeplechase runners": "عداؤو موانع ذكور",
    "male swimmers": "سباحون ذكور",
    "male synchronized swimmers": "سباحون إيقاعيون ذكور",
    "male table tennis players": "لاعبو كرة طاولة ذكور",
    "male taekwondo practitioners": "لاعبو تايكوندو ذكور",
    "male television actors": "ممثلو تلفزيون ذكور",
    "male tennis players": "لاعبو كرة مضرب ذكور",
    "male triathletes": "لاعبو ترياثلون ذكور",
    "male video game actors": "ممثلو ألعاب فيديو ذكور",
    "male violinists": "عازفو كمان ذكور",
    "male voice actors": "ممثلو أداء صوتي ذكور",
    "male water polo players": "لاعبو كرة ماء ذكور",
    "male web series actors": "ممثلو مسلسلات ويب ذكور",
    "male weightlifters": "رباعون ذكور",
    "male wheelchair basketball players": "لاعبو كرة سلة على كراسي متحركة ذكور",
    "male wrestlers": "مصارعون ذكور",
    "male writers": "كتاب ذكور",
}


@pytest.mark.parametrize("category, expected", test_mens_data.items(), ids=test_mens_data.keys())
@pytest.mark.fast
def test_prefix_bot_mens_1(category: str, expected: str) -> None:
    label = mens_resolver_labels(category)
    assert label == expected

    label2 = mens_resolver_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", test_mens_data2.items(), ids=test_mens_data2.keys())
@pytest.mark.fast
def test_prefix_bot_mens_2(category: str, expected: str) -> None:
    label = mens_resolver_labels(category)
    assert label == expected

    label2 = mens_resolver_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", test_mens_data_male.items(), ids=test_mens_data_male.keys())
@pytest.mark.fast
def test_prefix_bot_mens_male(category: str, expected: str) -> None:
    label = mens_resolver_labels(category)
    assert label == expected

    label2 = mens_resolver_labels(category)
    assert label2 == expected


TEMPORAL_CASES = [
    ("test_prefix_bot_mens_1", test_mens_data, mens_resolver_labels),
    ("test_prefix_bot_mens_2", test_mens_data2, mens_resolver_labels),
    ("test_prefix_bot_mens_male", test_mens_data_male, mens_resolver_labels),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



# -*- coding: utf-8 -*-
"""Pytest move_years"""

from ArWikiCats.fix.mv_years import move_years


def load_test_move_years(data: dict) -> None:
    diff_list = []
    same = 0
    for title, expected in data.items():
        result = move_years(title)
        if result != expected:
            diff_list.append({"input": title, "actual": result, "expected": expected})
        else:
            assert result == expected
            same += 1
    len_diff_list = len(diff_list)
    print(f"<<green>> {len_diff_list=}, {same=}.")

    if len_diff_list:
        diff_details = "\n".join(str(entry) for entry in diff_list)
        raise AssertionError(f"Found {len_diff_list} transformation mismatches: {diff_details}")


def test_fixlab_group_1() -> None:
    data = {
        "2010 في الرياضة في آيوا": "الرياضة في آيوا في 2010",
        "2010 في الرياضة في أريزونا": "الرياضة في أريزونا في 2010",
        "2020 في الرياضة في ألاباما": "الرياضة في ألاباما في 2020",
        "2020 في الرياضة في أوريغن": "الرياضة في أوريغن في 2020",
        "2020 في الرياضة في أوكلاهوما": "الرياضة في أوكلاهوما في 2020",
        "2020 في الرياضة في يوتا": "الرياضة في يوتا في 2020",
        "عقد 2010 في الرياضة في أوريغن": "الرياضة في أوريغن في عقد 2010",
    }
    load_test_move_years(data)


def test_fixlab_group_2() -> None:
    data = {
        "القرن 20 في الرياضة في إلينوي": "الرياضة في إلينوي في القرن 20",
        "القرن 20 في الرياضة في بنسلفانيا": "الرياضة في بنسلفانيا في القرن 20",
        "القرن 20 في الرياضة في رود آيلاند": "الرياضة في رود آيلاند في القرن 20",
        "القرن 20 في الرياضة في مدينة نيويورك": "الرياضة في مدينة نيويورك في القرن 20",
        "القرن 20 في الرياضة في ولاية نيويورك": "الرياضة في ولاية نيويورك في القرن 20",
        "القرن 20 في الرياضة في آيوا": "الرياضة في آيوا في القرن 20",
        "القرن 20 في الرياضة في أريزونا": "الرياضة في أريزونا في القرن 20",
        "القرن 20 في الرياضة في نيفادا": "الرياضة في نيفادا في القرن 20",
        "القرن 20 في الرياضة في نيومكسيكو": "الرياضة في نيومكسيكو في القرن 20",
        "القرن 20 في الرياضة في ولاية واشنطن": "الرياضة في ولاية واشنطن في القرن 20",
        "القرن 20 في الرياضة في ويسكونسن": "الرياضة في ويسكونسن في القرن 20",
        "القرن 20 في الرياضة في يوتا": "الرياضة في يوتا في القرن 20",
    }
    load_test_move_years(data)


def test_fixlab_group_3() -> None:
    data = {
        "عقد 1980 ق م في العراق": "العراق في عقد 1980 ق م",
        "عقد 1990 في السعودية": "السعودية في عقد 1990",
        "عقد 2010 في جنوب إفريقيا": "جنوب إفريقيا في عقد 2010",
        "عقد 2010 ق م في جنوب إفريقيا": "جنوب إفريقيا في عقد 2010 ق م",
        "عقد 2020 حسب المدينة والبلد في مجتمع في مدريد": "عقد 2020 حسب المدينة والبلد في مجتمع في مدريد",
        "عقد 2020 في ألعاب رياضية في أركنساس": "ألعاب رياضية في أركنساس في عقد 2020",
        "عقد 2020 في ألعاب رياضية في إلينوي": "ألعاب رياضية في إلينوي في عقد 2020",
        "عقد 2020 في الرياضة في آيوا": "الرياضة في آيوا في عقد 2020",
        "عقد 2020 في الرياضة في تينيسي": "الرياضة في تينيسي في عقد 2020",
        "عقد 2020 في الرياضة في رود آيلاند": "الرياضة في رود آيلاند في عقد 2020",
        "عقد 2020 في الرياضة في فرجينيا": "الرياضة في فرجينيا في عقد 2020",
        "عقد 2020 في الرياضة في فلوريدا": "الرياضة في فلوريدا في عقد 2020",
        "عقد 2020 في الرياضة في كارولاينا الشمالية": "الرياضة في كارولاينا الشمالية في عقد 2020",
        "عقد 2020 في الرياضة في كاليفورنيا": "الرياضة في كاليفورنيا في عقد 2020",
    }
    load_test_move_years(data)


def test_fixlab_group_4() -> None:
    data = {
        "عقد 2020 في الرياضة في كنتاكي": "الرياضة في كنتاكي في عقد 2020",
        "عقد 2020 في الرياضة في مدينة نيويورك": "الرياضة في مدينة نيويورك في عقد 2020",
        "عقد 2020 في الرياضة في وايومنغ": "الرياضة في وايومنغ في عقد 2020",
        "عقد 2020 في الرياضة في ولاية جورجيا": "الرياضة في ولاية جورجيا في عقد 2020",
        "عقد 2020 في الرياضة في ويسكونسن": "الرياضة في ويسكونسن في عقد 2020",
        "عقد 2020 في الرياضة في يوتا": "الرياضة في يوتا في عقد 2020",
        "عقد 2020 في مجتمع في مدريد حسب المدينة والبلد": "مجتمع في مدريد في عقد 2020 حسب المدينة والبلد",
        "عقد 2020 في مجتمع في مدريد": "مجتمع في مدريد في عقد 2020",
    }
    load_test_move_years(data)


def test_fixlab_group_5() -> None:
    data = {
        "1881 في الرياضة في رود آيلاند": "الرياضة في رود آيلاند في 1881",
        "1974–75 في دوريات كرة قدم لبنانية": "دوريات كرة قدم لبنانية في 1974–75",
        "1989 في اتحاد الرجبي حسب البلد": "اتحاد الرجبي في 1989 حسب البلد",
        "1995 في الإمارات": "الإمارات في 1995",
        "2020 في ألعاب رياضية في أركنساس": "ألعاب رياضية في أركنساس في 2020",
        "2020 في ألعاب رياضية في ألاباما": "ألعاب رياضية في ألاباما في 2020",
        "2020 في ألعاب رياضية في إلينوي": "ألعاب رياضية في إلينوي في 2020",
        "2020 في ألعاب رياضية في تكساس": "ألعاب رياضية في تكساس في 2020",
        "2020 في ألعاب رياضية في فلوريدا": "ألعاب رياضية في فلوريدا في 2020",
        "2020 في ألعاب رياضية في نيفادا": "ألعاب رياضية في نيفادا في 2020",
        "2020 في جنوب إفريقيا": "جنوب إفريقيا في 2020",
        "2020 في مجتمع في مدريد": "مجتمع في مدريد في 2020",
        "2020 في مصارعة المحترفين في فلوريدا": "مصارعة المحترفين في فلوريدا في 2020",
        "2020 في مناطق حضرية في لوس أنجلوس": "مناطق حضرية في لوس أنجلوس في 2020",
        "2020 في مولدوفا": "مولدوفا في 2020",
        "2020 ق م في جنوب إفريقيا": "جنوب إفريقيا في 2020 ق م",
        "آسيا حسب المدينة في القرن 17": "آسيا في القرن 17 حسب المدينة",
        "آسيا حسب المدينة في عقد 2020": "آسيا في عقد 2020 حسب المدينة",
        "أذربيجانيون حسب المهنة في القرن 20": "أذربيجانيون في القرن 20 حسب المهنة",
        "أشخاص أمريكيون شماليون حسب الجنسية في القرن 17": "أشخاص أمريكيون شماليون في القرن 17 حسب الجنسية",
        "أشخاص حسب النزاع في القرن 5 ق م": "أشخاص في القرن 5 ق م حسب النزاع",
        "الألفية 1 في اليمن": "اليمن في الألفية 1",
        "التلفاز في السويد حسب السنة": "التلفاز في السويد حسب السنة",
        "القرن 17 في أشخاص أمريكيون شماليون حسب الجنسية": "أشخاص أمريكيون شماليون في القرن 17 حسب الجنسية",
        "القرن 20 في مصر": "مصر في القرن 20",
        "القرن 20 ق م في مصر": "مصر في القرن 20 ق م",
        "القرن 21 أشخاص من العراق العثماني حسب المهنة": "القرن 21 أشخاص من العراق العثماني حسب المهنة",
        "القرن 21 في الأردن": "الأردن في القرن 21",
        "القرن 21 في جنوب إفريقيا": "جنوب إفريقيا في القرن 21",
        "القرن 21 في يونانيون في حسب المهنة": "يونانيون في القرن 21 حسب المهنة",
        "المرأة حسب المهنة والجنسية في القرن 19": "المرأة في القرن 19 حسب المهنة والجنسية",
        "المرأة في القرن 19 حسب المهنة والجنسية": "المرأة في القرن 19 حسب المهنة والجنسية",
        "رياضة حسب القارة في عقد 1940": "رياضة في عقد 1940 حسب القارة",
        "فلاسفة فرنسيون في القرن 20": "فلاسفة فرنسيون في القرن 20",
        "فنانون ذكور حسب الجنسية 2020": "فنانون ذكور حسب الجنسية 2020",
        "فنانون ذكور حسب الجنسية القرن 20": "فنانون ذكور حسب الجنسية القرن 20",
        "قضاة حسب الجنسية القرن 20": "قضاة حسب الجنسية القرن 20",
        "قضاة حسب الجنسية عقد 2010": "قضاة حسب الجنسية عقد 2010",
        "كنديون حسب الأصل العرقي أو الوطني في القرن 20": "كنديون في القرن 20 حسب الأصل العرقي أو الوطني",
        "مرشحون في انتخابات الولايات المتحدة حسب السنة في القرن 21": "مرشحون في انتخابات الولايات المتحدة في القرن 21 حسب السنة",
        "مسلسلات تلفزيونية كوميدية أمريكية حسب النوع الفني في عقد 1960": "مسلسلات تلفزيونية كوميدية أمريكية في عقد 1960 حسب النوع الفني",
        "ملكيون حسب البلد القرن 20": "ملكيون حسب البلد القرن 20",
        "منافسون في ألعاب الكومنولث حسب السنة في القرن 20": "منافسون في ألعاب الكومنولث في القرن 20 حسب السنة",
        "هجمات في كندا في عقد 2020": "هجمات في كندا في عقد 2020",
        "يونانيون حسب المهنة في القرن 9": "يونانيون في القرن 9 حسب المهنة",
    }
    load_test_move_years(data)



#!/usr/bin/python3
""" """

import functools
import re

from ...helps import logger
from ..sports.Sport_key import SPORTS_KEYS_FOR_JOBS

Sports_Keys_For_Jobs_simple = {
    "wheelchair automobile racing": "سباق سيارات على كراسي متحركة",
    "gaelic football racing": "سباق كرة قدم غالية",
    "wheelchair gaelic football": "كرة قدم غالية على كراسي متحركة",
    "kick boxing racing": "سباق كيك بوكسينغ",
    "wheelchair kick boxing": "كيك بوكسينغ على كراسي متحركة",
    "sport climbing racing": "سباق تسلق",
    "wheelchair sport climbing": "تسلق على كراسي متحركة",
    "aquatic sports racing": "سباق رياضات مائية",
    "wheelchair aquatic sports": "رياضات مائية على كراسي متحركة",
    "shooting": "رماية",
    "shooting racing": "سباق رماية",
    "wheelchair shooting": "رماية على كراسي متحركة",
    "motorsports racing": "سباق رياضة محركات",
    "futsal": "كرة صالات",
    "darts": "سهام مريشة",
    "basketball": "كرة سلة",
    "esports": "رياضة إلكترونية",
    "canoeing": "ركوب الكنو",
    "dressage": "ترويض خيول",
    "canoe sprint": "سباق قوارب",
    "gymnastics": "جمباز",
    "korfball": "كورفبال",
    "fifa futsal world cup racing": "سباق كأس العالم لكرة الصالات",
    "wheelchair fifa futsal world cup": "كأس العالم لكرة الصالات على كراسي متحركة",
    "fifa world cup racing": "سباق كأس العالم لكرة القدم",
    "wheelchair fifa world cup": "كأس العالم لكرة القدم على كراسي متحركة",
    "multi-sport racing": "سباق رياضية متعددة",
    "wheelchair multi-sport": "رياضية متعددة على كراسي متحركة",
    "beach handball racing": "سباق كرة يد شاطئية",
    "wheelchair beach handball": "كرة يد شاطئية على كراسي متحركة",
    "shot put racing": "سباق دفع ثقل",
    "wheelchair shot put": "دفع ثقل على كراسي متحركة",
}


@functools.lru_cache(maxsize=1)
def _load_regex() -> re.Pattern:
    """Return the compiled regex pattern for matching sport keys."""
    if len(SPORTS_KEYS_FOR_JOBS) > 1000:
        logger.debug(f">keys_to_pattern(): len(new_pattern keys) = {len(SPORTS_KEYS_FOR_JOBS):,}")

    data_List_sorted = sorted(
        SPORTS_KEYS_FOR_JOBS.keys(),
        key=lambda k: (-k.count(" "), -len(k)),
    )
    alternation = "|".join(map(re.escape, [n.lower() for n in data_List_sorted]))

    new_pattern = rf"(?<!\w)({alternation})(?!\w)"

    RE_KEYS_NEW = re.compile(new_pattern, re.I)

    return RE_KEYS_NEW


@functools.lru_cache(maxsize=10000)
def match_sport_key(category: str) -> str:
    """Return the matched sport key within the provided category string."""
    RE_KEYS_NEW = _load_regex()
    match = RE_KEYS_NEW.search(f" {category} ")
    if match:
        return match.group(1)
    return ""


__all__ = [
    "match_sport_key",
]



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new.resolve_films_bots.resolve_films_labels import _get_films_key_tyty_new

fast_data_with_nats = {
    "animated short film comics": "قصص مصورة رسوم متحركة قصيرة",
    # "Category:American animated television films": "تصنيف:أفلام رسوم متحركة تلفزيونية أمريكية",
    "northern ireland": "",
    "supernatural thriller films": "أفلام إثارة خارقة للطبيعة",
    "american animated short television series": "مسلسلات تلفزيونية رسوم متحركة قصيرة أمريكية",
    "american drama television series": "مسلسلات تلفزيونية درامية أمريكية",
    # nats
    "action classical albums": "ألبومات كلاسيكية حركة",
    "yemeni action classical albums": "ألبومات كلاسيكية حركة يمنية",
    "yemeni novellas": "روايات قصيرة يمنية",
    "yemeni films": "أفلام يمنية",
    "Yemeni action films": "أفلام حركة يمنية",
    "Yemeni action drama films": "أفلام حركة درامية يمنية",
    "Yemeni upcoming horror films": "أفلام رعب قادمة يمنية",
    "Yemeni horror upcoming films": "أفلام رعب قادمة يمنية",
    "Yemeni upcoming films": "أفلام قادمة يمنية",
    "heist japanese horror films": "أفلام سرقة رعب يابانية",
    "Yemeni action thriller adult animated supernatural films": "أفلام إثارة حركة رسوم متحركة خارقة للطبيعة للكبار يمنية",
}

fast_data_no_nats = {
    # films keys
    "3d low-budget films": "أفلام ثلاثية الأبعاد منخفضة التكلفة",
    "low-budget 3d films": "أفلام ثلاثية الأبعاد منخفضة التكلفة",
    "heist historical television commercials": "إعلانات تجارية تلفزيونية سرقة تاريخية",
    "adult animated supernatural films": "أفلام رسوم متحركة خارقة للطبيعة للكبار",
    "heist holocaust films": "أفلام سرقة هولوكوستية",
    "heist hood films": "أفلام سرقة هود",
    "heist horror films": "أفلام سرقة رعب",
    "heist independent films": "أفلام سرقة مستقلة",
    "heist interactive films": "أفلام سرقة تفاعلية",
    "heist internet films": "أفلام سرقة إنترنت",
    "heist joker films": "أفلام سرقة جوكر",
    "heist kaiju films": "أفلام سرقة كايجو",
    "heist kung fu films": "أفلام سرقة كونغ فو",
    "heist latin films": "أفلام سرقة لاتينية",
    "heist legal films": "أفلام سرقة قانونية",
    "psychological horror black-and-white films": "أفلام رعب نفسي أبيض وأسود",
    "psychological horror bollywood films": "أفلام رعب نفسي بوليوود",
    "action sports films": "أفلام حركة رياضية",
    "action spy films": "أفلام حركة تجسسية",
    "action street fighter films": "أفلام حركة قتال شوارع",
    "action student films": "أفلام حركة طلاب",
    "action submarines films": "أفلام حركة غواصات",
    "action super robot films": "أفلام حركة آلية خارقة",
    "action supernatural films": "أفلام حركة خارقة للطبيعة",
    "action supernatural drama films": "أفلام حركة دراما خارقة للطبيعة",
    "action survival films": "أفلام حركة البقاء على قيد الحياة",
    "action teen films": "أفلام حركة مراهقة",
    "action thriller 3d films": "أفلام إثارة حركة ثلاثية الأبعاد",
    "action thriller 4d films": "أفلام إثارة حركة رباعية الأبعاد",
    "action thriller action films": "أفلام إثارة حركة حركة",
    "action thriller action comedy films": "أفلام إثارة حركة حركة كوميدية",
    "action thriller adaptation films": "أفلام إثارة حركة مقتبسة",
    "action thriller adult animated films": "أفلام إثارة حركة رسوم متحركة للكبار",
    "action thriller adult animated drama films": "أفلام إثارة حركة رسوم متحركة دراما للكبار",
    "action thriller adult animated supernatural films": "أفلام إثارة حركة رسوم متحركة خارقة للطبيعة للكبار",
    "action thriller adventure films": "أفلام إثارة حركة مغامرات",
    "action thriller animated films": "أفلام إثارة حركة رسوم متحركة",
    "action thriller animated science films": "أفلام إثارة حركة علمية رسوم متحركة",
    "action thriller animated short films": "أفلام إثارة حركة رسوم متحركة قصيرة",
    "psychological horror buddy films": "أفلام رعب نفسي رفقاء",
    "psychological horror cancelled films": "أفلام رعب نفسي ملغية",
}


@pytest.mark.parametrize("category, expected", fast_data_no_nats.items(), ids=fast_data_no_nats.keys())
@pytest.mark.fast
def test_get_films_key_tyty(category: str, expected: str) -> None:
    label2 = _get_films_key_tyty_new(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", fast_data_with_nats.items(), ids=fast_data_with_nats.keys())
@pytest.mark.fast
def test_fast_data_with_nats(category: str, expected: str) -> None:
    label2 = _get_films_key_tyty_new(category)
    assert label2 == expected


to_test = [
    ("test_get_films_key_tyty", fast_data_no_nats, _get_films_key_tyty_new),
    ("test_fast_data_with_nats", fast_data_with_nats, _get_films_key_tyty_new),
]


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests for country2_label_bot module functions.
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import country_2_title_work

title_work_tests_data = {
    # "mass media in bosnia and herzegovina": "وسائل إعلام في البوسنة والهرسك",
    # "mass media in morocco": "وسائل إعلام في المغرب",
    # "1520 films by country": "أفلام 1520 حسب البلد",
    " kingdom-of italy": "مملكة إيطاليا",
    "1520 by country": "1520 حسب البلد",
    "1520 crimes in africa": "جرائم 1520 في إفريقيا",
    "1520 elections in united states": "انتخابات 1520 في الولايات المتحدة",
    "1520 in antigua and barbuda": "1520 في أنتيغوا وباربودا",
    "1520 in asian sport": "1520 في رياضة آسيوية",
    "1520 in brazilian sport": "1520 في رياضة برازيلية",
    "1520 in canada": "1520 في كندا",
    "1520 in china": "1520 في الصين",
    "1520 in chinese sport": "1520 في رياضة صينية",
    "1520 in football": "1520 في كرة القدم",
    "1520 in men's football": "1520 في كرة القدم للرجال",
    "1520 in men's international football": "1520 في كرة قدم دولية للرجال",
    "1520 in mexico": "1520 في المكسيك",
    "1520 in north america": "1520 في أمريكا الشمالية",
    "1520 in rugby union": "1520 في اتحاد الرجبي",
    "1520 in south america": "1520 في أمريكا الجنوبية",
    "1520 in south american football": "1520 في كرة القدم الأمريكية الجنوبية",
    "1520 in taiwan": "1520 في تايوان",
    "1520 in television": "1520 في التلفاز",
    "1520 in thailand": "1520 في تايلاند",
    "1520 in united kingdom": "1520 في المملكة المتحدة",
    "1520 in united states": "1520 في الولايات المتحدة",
    "1520 in women's sport": "1520 في رياضة نسائية",
    "1520 in yemen": "1520 في اليمن",
    "1520 in youth football": "1520 في كرة القدم للشباب",
    "1520s in asia": "عقد 1520 في آسيا",
    "1520s in united states": "عقد 1520 في الولايات المتحدة",
    "1520–95 in european rugby union": "1520–95 في اتحاد الرجبي الأوروبي",
    "20th century in iraq": "القرن 20 في العراق",
    "ambassadors of afghanistan": "سفراء أفغانستان",
    "ambassadors of algeria": "سفراء الجزائر",
    "ambassadors of austria": "سفراء النمسا",
    "ambassadors of brazil": "سفراء البرازيل",
    "ambassadors of canada": "سفراء كندا",
    "ambassadors of chad": "سفراء تشاد",
    "ambassadors of china": "سفراء الصين",
    "ambassadors of federated states-of micronesia": "سفراء ولايات ميكرونيسيا المتحدة",
    "ambassadors of fiji": "سفراء فيجي",
    "ambassadors of ghana": "سفراء غانا",
    "ambassadors of great britain": "سفراء بريطانيا العظمى",
    "ambassadors of italy": "سفراء إيطاليا",
    "ambassadors of japan": "سفراء اليابان",
    "ambassadors of palau": "سفراء بالاو",
    "ambassadors of south africa": "سفراء جنوب إفريقيا",
    "ambassadors of united states": "سفراء الولايات المتحدة",
    "ambassadors to ottoman empire": "سفراء إلى الدولة العثمانية",
    "archaeology of europe": "علم الآثار في أوروبا",
    "arizona in fiction": "أريزونا في الخيال",
    "attacks on military installations": "هجمات على منشآت عسكرية",
    "baseball playerss in florida": "لاعبو كرة قاعدة في فلوريدا",
    "baseball playerss in south korea": "لاعبو كرة قاعدة في كوريا الجنوبية",
    "basketball playerss in lebanon": "لاعبو كرة سلة في لبنان",
    "battles of napoleonic wars": "معارك الحروب النابليونية",
    "battles of vietnam war": "معارك حرب فيتنام",
    "bridges in france": "جسور في فرنسا",
    "buildings and structures in 1520": "مبان ومنشآت في 1520",
    "buildings and structures in africa": "مبان ومنشآت في إفريقيا",
    "buildings and structures in georgia (u.s. state)": "مبان ومنشآت في ولاية جورجيا",
    "buildings and structures in idaho": "مبان ومنشآت في أيداهو",
    "buildings and structures in prince edward island": "مبان ومنشآت في جزيرة الأمير إدوارد",
    "burials in washington (state)": "مدفونون في ولاية واشنطن",
    "by city in colombia": "حسب المدينة في كولومبيا",
    "by city in northern-ireland": "حسب المدينة في أيرلندا الشمالية",
    "by county in taiwan": "حسب المقاطعة في تايوان",
    "by educational institution in derbyshire": "حسب الهيئة التعليمية في داربيشير",
    "by league in united states": "حسب الدوري في الولايات المتحدة",
    "by newspaper in california": "حسب الصحيفة في كاليفورنيا",
    "by team in united states": "حسب الفريق في الولايات المتحدة",
    "by university or college in beijing": "حسب الجامعة أو الكلية في بكين",
    "by university or college in guatemala": "حسب الجامعة أو الكلية في غواتيمالا",
    "by university or college in india": "حسب الجامعة أو الكلية في الهند",
    "by university or college in mauritius": "حسب الجامعة أو الكلية في موريشيوس",
    "by university or college in nebraska": "حسب الجامعة أو الكلية في نبراسكا",
    "by university or college in north carolina": "حسب الجامعة أو الكلية في كارولاينا الشمالية",
    "canadian ice hockey by league": "هوكي الجليد الكندية حسب الدوري",
    "canadian ice hockey by team": "هوكي الجليد الكندية حسب الفريق",
    "christianity in united states": "المسيحية في الولايات المتحدة",
    "city of zagreb": "مدينة زغرب",
    "companies of georgia (country)": "شركات في جورجيا",
    "companies of southeast asia": "شركات في جنوب شرق آسيا",
    "covid-19 pandemic in paraná (state)": "جائحة فيروس كورونا في ولاية بارانا",
    "crimes in peru": "جرائم في بيرو",
    "croatian war of independence": "الحرب الكرواتية في استقلال",
    "disestablishments in ecuador": "انحلالات في الإكوادور",
    "disestablishments in georgia (u.s. state)": "انحلالات في ولاية جورجيا",
    "disestablishments in yugoslavia": "انحلالات في يوغسلافيا",
    "education in france": "تعليم في فرنسا",
    "education in israel": "تعليم في إسرائيل",
    "education in united states": "تعليم في الولايات المتحدة",
    "establishments in guernsey": "تأسيسات في غيرنزي",
    "establishments in southeast asia": "تأسيسات في جنوب شرق آسيا",
    "ethnic groups in china": "مجموعات عرقية في الصين",
    "fauna of vermont": "حيوانات فيرمونت",
    "federalist party members of united states house-of-representatives": "أعضاء الحزب الفيدرالي الأمريكي في مجلس النواب الأمريكي",
    "field hockey playerss in germany": "لاعبو هوكي ميدان في ألمانيا",
    "films basedon non-fiction books about organized crime": "أفلام مبنية على كتب غير خيالية عن جريمة منظمة",
    "fishes of europe": "أسماك أوروبا",
    "food and drink in europe": "أطعمة ومشروبات في أوروبا",
    "french invasion of egypt and syria": "الغزو الفرنسي في مصر وسوريا",
    "geography of kansas": "جغرافيا كانساس",
    "georgia (u.s. state) in fiction": "ولاية جورجيا في الخيال",
    "government of burkina faso": "حكومة بوركينا فاسو",
    "government of turkey": "حكومة تركيا",
    "high schools in india": "مدارس ثانوية في الهند",
    "historic districts in massachusetts": "المناطق التاريخية في ماساتشوستس",
    "history of austria hungary": "تاريخ الإمبراطورية النمساوية المجرية",
    "history of central african republic": "تاريخ جمهورية إفريقيا الوسطى",
    "history of copenhagen": "تاريخ كوبنهاغن",
    "history of north america": "تاريخ أمريكا الشمالية",
    "history of northern ireland": "تاريخ أيرلندا الشمالية",
    "history of nova scotia": "تاريخ نوفا سكوشا",
    "history of petroleum industry": "تاريخ صناعة بترولية",
    "immigration to europe": "الهجرة إلى أوروبا",
    "immigration to united states": "الهجرة إلى الولايات المتحدة",
    "impact of covid-19 pandemic": "تأثيرات جائحة فيروس كورونا",
    "indigenous peoples of americas": "شعوب أصلية في الأمريكتين",
    "installations of united states air force": "منشآت في القوات الجوية الأمريكية",
    "iowa in fiction": "آيوا في الخيال",
    "kingdom-of italy (1520–1520)": "مملكة إيطاليا (1520–1520)",
    "know-nothing members of united states house-of-representatives": "أعضاء حزب لا أدري في مجلس النواب الأمريكي",
    "lists of ambassadors": "قوائم سفراء",
    "lists of bosnia and herzegovina people": "قوائم بوسنيون",
    "lists of country subdivisions": "قوائم تقسيمات البلد",
    "lists of legislators": "قوائم مشرعون",
    "lists of roads": "قوائم طرقات",
    "members of maine legislature": "أعضاء هيئة مين التشريعية",
    "military operations of american civil war": "عمليات عسكرية في الحرب الأهلية الأمريكية",
    "military operations of syrian civil war": "عمليات عسكرية في الحرب الأهلية السورية",
    "military operations of war in afghanistan (1520–1520)": "عمليات عسكرية في الحرب في أفغانستان (1520–1520)",
    "military operations of war": "عمليات عسكرية في الحرب",
    "montana in fiction": "مونتانا في الخيال",
    "national-register-of-historic-places in north carolina": "السجل الوطني للأماكن التاريخية في كارولاينا الشمالية",
    "nations in summer olympics": "بلدان في الألعاب الأولمبية الصيفية",
    "nebraska in fiction": "نبراسكا في الخيال",
    "netball in north america": "كرة الشبكة في أمريكا الشمالية",
    "new mexico in fiction": "نيومكسيكو في الخيال",
    "non-profit organizations of brazil": "منظمات غير ربحية في البرازيل",
    "non-profit organizations of canada": "منظمات غير ربحية في كندا",
    "non-profit organizations of chile": "منظمات غير ربحية في تشيلي",
    "non-profit organizations of colombia": "منظمات غير ربحية في كولومبيا",
    "non-profit organizations of costa rica": "منظمات غير ربحية في كوستاريكا",
    "non-profit organizations of united kingdom": "منظمات غير ربحية في المملكة المتحدة",
    "non-profit organizations of united states": "منظمات غير ربحية في الولايات المتحدة",
    "northern ireland of canadian descent": "أيرلندا الشمالية في أصل كندي",
    "order of british empire": "وسام الإمبراطورية البريطانية",
    "organizations based in gabon": "منظمات مقرها في الغابون",
    "ottoman empire by decade": "الدولة العثمانية حسب العقد",
    "parks in south america": "متنزهات في أمريكا الجنوبية",
    "parliament of barbados": "برلمان بربادوس",
    "parliament of england 1520": "برلمان إنجلترا 1520",
    "parliament of great britain": "برلمان بريطانيا العظمى",
    "parliament of ireland 1520": "برلمان أيرلندا 1520",
    "parliament of northern ireland 1520–1520": "برلمان أيرلندا الشمالية 1520–1520",
    "prime ministers of japan": "رؤساء وزراء اليابان",
    "prime ministers of ukraine": "رؤساء وزراء أوكرانيا",
    "protected areas of georgia (u.s. state)": "مناطق محمية في ولاية جورجيا",
    "railway stations in albania": "محطات السكك الحديدية في ألبانيا",
    "railway stations in austria": "محطات السكك الحديدية في النمسا",
    "railway stations in bangladesh": "محطات السكك الحديدية في بنغلاديش",
    "railway stations in canada": "محطات السكك الحديدية في كندا",
    "railway stations in denmark": "محطات السكك الحديدية في الدنمارك",
    "railway stations in france": "محطات السكك الحديدية في فرنسا",
    "railway stations in germany": "محطات السكك الحديدية في ألمانيا",
    "railway stations in great britain": "محطات السكك الحديدية في بريطانيا العظمى",
    "railway stations in hong kong": "محطات السكك الحديدية في هونغ كونغ",
    "railway stations in indonesia": "محطات السكك الحديدية في إندونيسيا",
    "railway stations in japan": "محطات السكك الحديدية في اليابان",
    "railway stations in latvia": "محطات السكك الحديدية في لاتفيا",
    "railway stations in netherlands": "محطات السكك الحديدية في هولندا",
    "railway stations in new zealand": "محطات السكك الحديدية في نيوزيلندا",
    "railway stations in north korea": "محطات السكك الحديدية في كوريا الشمالية",
    "railway stations in northern-ireland": "محطات السكك الحديدية في أيرلندا الشمالية",
    "railway stations in philippines": "محطات السكك الحديدية في الفلبين",
    "railway stations in poland": "محطات السكك الحديدية في بولندا",
    "railway stations in republic-of ireland": "محطات السكك الحديدية في جمهورية أيرلندا",
    "railway stations in romania": "محطات السكك الحديدية في رومانيا",
    "railway stations in russia": "محطات السكك الحديدية في روسيا",
    "railway stations in russian empire": "محطات السكك الحديدية في الإمبراطورية الروسية",
    "railway stations in serbia": "محطات السكك الحديدية في صربيا",
    "railway stations in south korea": "محطات السكك الحديدية في كوريا الجنوبية",
    "railway stations in spain": "محطات السكك الحديدية في إسبانيا",
    "railway stations in sweden": "محطات السكك الحديدية في السويد",
    "railway stations in united kingdom": "محطات السكك الحديدية في المملكة المتحدة",
    "railway stations in united states": "محطات السكك الحديدية في الولايات المتحدة",
    "religion in united states": "الدين في الولايات المتحدة",
    "rivers of united states": "أنهار الولايات المتحدة",
    "road incident deaths in united states": "وفيات حوادث الطرق في الولايات المتحدة",
    "saint kitts and nevis in summer olympics": "سانت كيتس ونيفيس في الألعاب الأولمبية الصيفية",
    "shopping malls in ukraine": "مراكز تسوق في أوكرانيا",
    "skyscrapers in united arab emirates": "ناطحات سحاب في الإمارات العربية المتحدة",
    "sports governing bodies in north america": "هيئات تنظيم رياضية في أمريكا الشمالية",
    "sports venues in australia": "ملاعب رياضية في أستراليا",
    "synagogues in switzerland": "كنس في سويسرا",
    "tanks of united states": "دبابات الولايات المتحدة",
    "tourism in republic-of ireland": "سياحة في جمهورية أيرلندا",
    "tourism in united kingdom": "سياحة في المملكة المتحدة",
    "trade unions in caribbean": "نقابات عمالية في الكاريبي",
    "transport infrastructure in south america": "البنية التحتية للنقل في أمريكا الجنوبية",
    "transportation buildings and structures in new hampshire": "مبان ومنشآت نقل في نيوهامشير",
    "unincorporated communities in alaska": "مجتمعات فردية في ألاسكا",
    "united nations in geneva": "الأمم المتحدة في جنيف",
    "united states by state or territory": "الولايات المتحدة حسب الولاية أو الإقليم",
    "united states in 1520": "الولايات المتحدة في 1520",
    "united states navy to royal navy": "البحرية الأمريكية إلى البحرية الملكية",
    "universities and colleges in andhra pradesh": "جامعات وكليات في أندرا برديش",
    "universities and colleges in ghana": "جامعات وكليات في غانا",
    "universities and colleges in texas": "جامعات وكليات في تكساس",
    "universities and colleges in ukraine": "جامعات وكليات في أوكرانيا",
    "universities and colleges in uruguay": "جامعات وكليات في أوروغواي",
    "university of galway": "جامعة جلوي",
    "university of sheffield": "جامعة شفيلد",
    "verkhovna rada of ukrainian soviet socialist republic": "المجلس الأعلى الأوكراني في جمهورية أوكرانيا السوفيتية الاشتراكية",
    "villages in north macedonia": "قرى في مقدونيا الشمالية",
    "volleyball competitions in asia": "منافسات كرة طائرة في آسيا",
    "war of 1520": "حرب 1520",
    "water of coquimbo region": "مياه في إقليم كوكيمبو",
    "water of hambantota district": "مياه في مديرية هامبانتوتا",
    "water of matale district": "مياه في مديرية ماتال",
    "water of novosibirsk oblast": "مياه في نوفوسيبيرسك أوبلاست",
    "water of wilkes land": "مياه في ويلكس لاند",
    "wheelchair basketball playerss in turkey": "لاعبو كرة سلة على كراسي متحركة في تركيا",
    "whig party members of united states house-of-representatives": "أعضاء حزب اليمين في مجلس النواب الأمريكي",
    "wisconsin in fiction": "ويسكونسن في الخيال",
    "women's footballers in ireland": "لاعبات كرة قدم في أيرلندا",
    "years of 16th century": "سنوات القرن 16",
    "years of 17th century": "سنوات القرن 17",
    "years of 18th century": "سنوات القرن 18",
    "years of 19th century": "سنوات القرن 19",
}

test_2 = {}

data_2 = {
    "sport in ottoman empire": "الرياضة في الدولة العثمانية",
    "sports in ottoman empire": "الرياضة في الدولة العثمانية",
}


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", title_work_tests_data.items(), ids=title_work_tests_data.keys())
def test_data_based_in(category: str, expected: str) -> None:
    result = country_2_title_work(category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_2.items(), ids=data_2.keys())
def test_data_based_in_data_2(category: str, expected: str) -> None:
    result = country_2_title_work(category)
    assert result == expected


to_test = [
    ("title_work_tests_data", title_work_tests_data, country_2_title_work),
    ("test_2", test_2, country_2_title_work),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Build comprehensive gendered job label dictionaries.
"""

from __future__ import annotations

from dataclasses import dataclass
from typing import Dict, List, Mapping, MutableMapping

from ...helps import len_print
from ..mixed.all_keys2 import BOOK_CATEGORIES
from ..mixed.female_keys import RELIGIOUS_FEMALE_KEYS
from ..nats.Nationality import Nat_mens
from ..sports.cycling import BASE_CYCLING_EVENTS
from ..utils.json_dir import open_json_file
from .Jobs2 import JOBS_2, JOBS_3333
from .jobs_data_basic import MEN_WOMENS_JOBS_2, NAT_BEFORE_OCC, RELIGIOUS_KEYS_PP
from .jobs_defs import (
    GenderedLabel,
    GenderedLabelMap,
    copy_gendered_map,
    merge_gendered_maps,
)
from .jobs_players_list import FOOTBALL_KEYS_PLAYERS, PLAYERS_TO_MEN_WOMENS_JOBS, SPORT_JOB_VARIANTS
from .jobs_singers import MEN_WOMENS_SINGERS, MEN_WOMENS_SINGERS_BASED
from .jobs_womens import short_womens_jobs

# ---------------------------------------------------------------------------
# Helper utilities
# ---------------------------------------------------------------------------

companies_to_jobs = {
    "mass media owners": {"males": "ملاك وسائل إعلام", "females": "مالكات وسائل إعلام"},
    "media owners": {"males": "ملاك إعلامية", "females": "مالكات إعلامية"},
    "magazine founders": {"males": "مؤسسو مجلات", "females": "مؤسسات مجلات"},
    "television company founders": {"males": "مؤسسو شركات تلفاز", "females": "مؤسسات شركات تلفاز"},
    "technology company founders": {"males": "مؤسسو شركات تقانة", "females": "مؤسسات شركات تقانة"},
    "mass media company founders": {"males": "مؤسسو شركات وسائل إعلام", "females": "مؤسسات شركات وسائل إعلام"},
    "media company founders": {"males": "مؤسسو شركات إعلامية", "females": "مؤسسات شركات إعلامية"},
    "financial company founders": {"males": "مؤسسو شركات مالية", "females": "مؤسسات شركات مالية"},
    "retail company founders": {"males": "مؤسسو شركات تجارة التجزئة", "females": "مؤسسات شركات تجارة التجزئة"},
    "internet company founders": {"males": "مؤسسو شركات إنترنت", "females": "مؤسسات شركات إنترنت"},
    "drink company founders": {"males": "مؤسسو شركات مشروبات", "females": "مؤسسات شركات مشروبات"},
    "publishing company founders": {"males": "مؤسسو شركات نشر", "females": "مؤسسات شركات نشر"},
    "entertainment company founders": {"males": "مؤسسو شركات ترفيه", "females": "مؤسسات شركات ترفيه"},
    "food company founders": {"males": "مؤسسو شركات أطعمة", "females": "مؤسسات شركات أطعمة"},
    "real estate company founders": {"males": "مؤسسو شركات عقارية", "females": "مؤسسات شركات عقارية"},
    "food and drink company founders": {
        "males": "مؤسسو شركات أطعمة ومشروبات",
        "females": "مؤسسات شركات أطعمة ومشروبات",
    },
    "pharmaceutical company founders": {"males": "مؤسسو شركات أدوية", "females": "مؤسسات شركات أدوية"},
    "shipping company founders": {"males": "مؤسسو شركات نقل بحري", "females": "مؤسسات شركات نقل بحري"},
    "airline founders": {"males": "مؤسسو خطوط جوية", "females": "مؤسسات خطوط جوية"},
    "construction and civil engineering company founders": {
        "males": "مؤسسو شركات بناء وهندسة مدنية",
        "females": "مؤسسات شركات بناء وهندسة مدنية",
    },
    "engineering company founders": {"males": "مؤسسو شركات هندسية", "females": "مؤسسات شركات هندسية"},
    "design company founders": {"males": "مؤسسو شركات تصميم", "females": "مؤسسات شركات تصميم"},
    "energy company founders": {"males": "مؤسسو شركات طاقة", "females": "مؤسسات شركات طاقة"},
    "health care company founders": {"males": "مؤسسو شركات رعاية صحية", "females": "مؤسسات شركات رعاية صحية"},
    "manufacturing company founders": {"males": "مؤسسو شركات تصنيع", "females": "مؤسسات شركات تصنيع"},
    "media founders": {"males": "مؤسسو وسائل إعلامية", "females": "مؤسسات وسائل إعلامية"},
    "mining company founders": {"males": "مؤسسو شركات تعدين", "females": "مؤسسات شركات تعدين"},
    "transport company founders": {"males": "مؤسسو شركات نقل", "females": "مؤسسات شركات نقل"},
}


def _append_list_unique(sequence: List[str], value: str) -> None:
    """Append ``value`` to ``sequence`` if it is not already present."""

    if value not in sequence:
        sequence.append(value)


# ---------------------------------------------------------------------------
# Static configuration
# ---------------------------------------------------------------------------

JOBS_2020_BASE: GenderedLabelMap = {
    "ecosocialists": {"males": "إيكولوجيون", "females": "إيكولوجيات"},
    "wheelchair tennis players": {
        "males": "لاعبو كرة مضرب على الكراسي المتحركة",
        "females": "لاعبات كرة مضرب على الكراسي المتحركة",
    },
}

DISABILITY_LABELS: GenderedLabelMap = {
    "deaf": {"males": "صم", "females": "صم"},
    "blind": {"males": "مكفوفون", "females": "مكفوفات"},
    "deafblind": {"males": "صم ومكفوفون", "females": "صم ومكفوفات"},
}

EXECUTIVE_DOMAINS: Mapping[str, str] = {
    "railroad": "سكك حديدية",
    "media": "وسائل إعلام",
    "public transportation": "نقل عام",
    "film studio": "استوديوهات أفلام",
    "advertising": "إعلانات",
    "music industry": "صناعة الموسيقى",
    "newspaper": "جرائد",
    "radio": "مذياع",
    "television": "تلفاز",
}

TYPI_LABELS: Mapping[str, GenderedLabel] = {
    "classical": {"males": "كلاسيكيون", "females": "كلاسيكيات"},
    "historical": {"males": "تاريخيون", "females": "تاريخيات"},
}

JOBS_TYPE_TRANSLATIONS: Mapping[str, str] = {
    "adventure": "مغامرة",
    "alternate history": "تاريخ بديل",
    "animated": "رسوم متحركة",
    "science fiction action": "خيال علمي وحركة",
}

JOBS_PEOPLE_ROLES: Mapping[str, GenderedLabel] = {
    "bloggers": {"males": "مدونون", "females": "مدونات"},
    "writers": {"males": "كتاب", "females": "كاتبات"},
    "news anchors": {"males": "مذيعو أخبار", "females": "مذيعات أخبار"},
    "non-fiction writers": {"males": "كتاب غير روائيين", "females": "كاتبات غير روائيات"},
    "critics": {"males": "نقاد", "females": "ناقدات"},
    "personalities": {"males": "شخصيات", "females": "شخصيات"},
    "journalists": {"males": "صحفيو", "females": "صحفيات"},
    "producers": {"males": "منتجو", "females": "منتجات"},
    "authors": {"males": "مؤلفو", "females": "مؤلفات"},
    "editors": {"males": "محررو", "females": "محررات"},
    "artists": {"males": "فنانو", "females": "فنانات"},
    "directors": {"males": "مخرجو", "females": "مخرجات"},
    "publisherspeople": {"males": "ناشرو", "females": "ناشرات"},
    "publishers (people)": {"males": "ناشرو", "females": "ناشرات"},
    "presenters": {"males": "مذيعو", "females": "مذيعات"},
    "creators": {"males": "مبتكرو", "females": "مبتكرات"},
}

jobs_data = open_json_file("jobs/jobs.json")

JOBS_2020_BASE.update({x: v for x, v in jobs_data["JOBS_2020"].items() if v.get("males") and v.get("females")})

JOBS_TYPE_TRANSLATIONS.update({x: v for x, v in jobs_data["JOBS_TYPE"].items() if v})  # v is string


FILM_ROLE_LABELS: Mapping[str, GenderedLabel] = {
    "filmmakers": {"males": "صانعو أفلام", "females": "صانعات أفلام"},
    "film editors": {"males": "محررو أفلام", "females": "محررات أفلام"},
    "film directors": {"males": "مخرجو أفلام", "females": "مخرجات أفلام"},
    "film producers": {"males": "منتجو أفلام", "females": "منتجات أفلام"},
    "film critics": {"males": "نقاد أفلام", "females": "ناقدات أفلام"},
    "film historians": {"males": "مؤرخو أفلام", "females": "مؤرخات أفلام"},
    "cinema editors": {"males": "محررون سينمائون", "females": "محررات سينمائيات"},
    "cinema directors": {"males": "مخرجون سينمائون", "females": "مخرجات سينمائيات"},
    "cinema producers": {"males": "منتجون سينمائون", "females": "منتجات سينمائيات"},
}


# ---------------------------------------------------------------------------
# Data containers
# ---------------------------------------------------------------------------


@dataclass
class JobsDataset:
    """Aggregate all exported job dictionaries."""

    males_jobs: Dict[str, str]
    females_jobs: Dict[str, str]


# ---------------------------------------------------------------------------
# Builders
# ---------------------------------------------------------------------------


def _build_jobs_2020() -> GenderedLabelMap:
    """Return the 2020 job dictionary merged with ministerial categories."""

    jobs_2020 = copy_gendered_map(JOBS_2020_BASE)
    return jobs_2020


def _extend_with_religious_jobs(base_jobs: GenderedLabelMap) -> GenderedLabelMap:
    """Add religious role combinations and their activist variants."""

    jobs = copy_gendered_map(base_jobs)
    for religion_key, labels in RELIGIOUS_KEYS_PP.items():
        jobs[religion_key] = {"males": labels["males"], "females": labels["females"]}
        activist_key = f"{religion_key} activists"
        jobs[activist_key] = {"males": f"ناشطون {labels['males']}", "females": f"ناشطات {labels['females']}"}
    return jobs


def _extend_with_disability_jobs(base_jobs: GenderedLabelMap) -> GenderedLabelMap:
    """Insert disability-focused job labels and executive variants."""

    jobs = copy_gendered_map(base_jobs)
    merge_gendered_maps(jobs, DISABILITY_LABELS)
    for domain_key, domain_label in EXECUTIVE_DOMAINS.items():
        if not domain_label:
            continue
        jobs[f"{domain_key} executives"] = {"males": f"مدراء {domain_label}", "females": f"مديرات {domain_label}"}
    return jobs


def _merge_jobs_sources() -> GenderedLabelMap:
    """Combine JSON sources and static configuration into a single map."""

    jobs_pp = open_json_file("jobs/jobs_Men_Womens_PP.json")
    jobs_pp.update(
        {
            "candidates": {"males": "مرشحون", "females": "مرشحات"},
            "presidential candidates": {"males": "مرشحون رئاسيون", "females": "مرشحات رئاسيات"},
            "political candidates": {"males": "مرشحون سياسيون", "females": "مرشحات سياسيات"},
        }
    )

    jobs_pp["coaches"] = {"males": "مدربون", "females": "مدربات"}
    # jobs_pp["sports coaches"] = {"males": "مدربون رياضيون", "females": "مدربات رياضيات"}
    jobs_pp.setdefault("men", {"males": "رجال", "females": ""})

    jobs_pp = _extend_with_religious_jobs(jobs_pp)
    jobs_pp = _extend_with_disability_jobs(jobs_pp)

    jobs_2020 = _build_jobs_2020()
    for job_name, labels in jobs_2020.items():
        if labels["males"] and labels["females"]:
            lowered = job_name.lower()
            if lowered not in jobs_pp:
                jobs_pp[lowered] = {"males": labels["males"], "females": labels["females"]}

    for category, labels in FOOTBALL_KEYS_PLAYERS.items():
        lowered = category.lower()
        if lowered not in jobs_pp:
            jobs_pp[lowered] = {"males": labels["males"], "females": labels["females"]}

    jobs_pp["fashion journalists"] = {"males": "صحفيو موضة", "females": "صحفيات موضة"}
    jobs_pp["zionists"] = {"males": "صهاينة", "females": "صهيونيات"}

    merge_gendered_maps(jobs_pp, companies_to_jobs)

    for religion_key, feminine_label in RELIGIOUS_FEMALE_KEYS.items():
        founder_key = f"{religion_key} founders"
        jobs_pp[founder_key] = {"males": f"مؤسسو {feminine_label}", "females": f"مؤسسات {feminine_label}"}

    jobs_pp["imprisoned abroad"] = {"males": "مسجونون في الخارج", "females": "مسجونات في الخارج"}
    jobs_pp["imprisoned"] = {"males": "مسجونون", "females": "مسجونات"}
    jobs_pp["escapees"] = {"males": "هاربون", "females": "هاربات"}
    jobs_pp["prison escapees"] = {"males": "هاربون من السجن", "females": "هاربات من السجن"}
    jobs_pp["missionaries"] = {"males": "مبشرون", "females": "مبشرات"}
    jobs_pp["venerated"] = {"males": "مبجلون", "females": "مبجلات"}

    return jobs_pp


def _add_jobs_from_jobs2(jobs_pp: GenderedLabelMap) -> GenderedLabelMap:
    """Merge entries from :mod:`Jobs2` that are missing from ``jobs_pp``."""

    merged = copy_gendered_map(jobs_pp)
    sources = [JOBS_2, JOBS_3333]
    for source in sources:
        for job_key, labels in source.items():
            lowered = job_key.lower()
            if lowered not in merged and (labels["males"] or labels["females"]):
                merged[lowered] = {"males": labels["males"], "females": labels["females"]}

    return merged


def _load_activist_jobs(m_w_jobs: MutableMapping[str, GenderedLabel], nat_before_occ: List[str]) -> None:
    """Extend ``m_w_jobs`` with activist categories from JSON."""

    activists = open_json_file("jobs/activists_keys.json")
    for category, labels in activists.items():
        lowered = category.lower()
        _append_list_unique(nat_before_occ, lowered)
        m_w_jobs[lowered] = {"males": labels["males"], "females": labels["females"]}


def _add_sport_variants(
    base_jobs: Mapping[str, GenderedLabel],
) -> dict[str, GenderedLabel]:
    """
    Derive sport, professional, and wheelchair variants for job labels.

    added 4605 new items (base_jobs: 1535*3)
    """
    data: dict[str, GenderedLabel] = {}
    for base_key, base_labels in base_jobs.items():
        lowered = base_key.lower()
        data[f"sports {lowered}"] = {
            "males": f"{base_labels['males']} رياضيون",
            "females": f"{base_labels['females']} رياضيات",
        }
        data[f"professional {lowered}"] = {
            "males": f"{base_labels['males']} محترفون",
            "females": f"{base_labels['females']} محترفات",
        }
        data[f"wheelchair {lowered}"] = {
            "males": f"{base_labels['males']} على الكراسي المتحركة",
            "females": f"{base_labels['females']} على الكراسي المتحركة",
        }
    return data


def _add_cycling_variants(nat_before_occ: List[str]) -> dict[str, GenderedLabel]:
    """Insert variants derived from cycling events."""
    data: dict[str, GenderedLabel] = {}
    for event_key, event_label in BASE_CYCLING_EVENTS.items():
        lowered = event_key.lower()
        data[f"{lowered} cyclists"] = {"males": f"دراجو {event_label}", "females": f"دراجات {event_label}"}

        winners_key = f"{lowered} winners"
        stage_winners_key = f"{lowered} stage winners"

        data[winners_key] = {"males": f"فائزون في {event_label}", "females": f"فائزات في {event_label}"}
        data[stage_winners_key] = {
            "males": f"فائزون في مراحل {event_label}",
            "females": f"فائزات في مراحل {event_label}",
        }
        _append_list_unique(nat_before_occ, winners_key)
        _append_list_unique(nat_before_occ, stage_winners_key)

    return data


def _add_jobs_people_variants() -> dict[str, GenderedLabel]:
    """Create combinations of people-centric roles with book genres and types."""
    data: dict[str, GenderedLabel] = {}
    for role_key, role_labels in JOBS_PEOPLE_ROLES.items():
        if not (role_labels["males"] and role_labels["females"]):
            continue
        for book_key, book_label in BOOK_CATEGORIES.items():
            data[f"{book_key} {role_key}"] = {
                "males": f"{role_labels['males']} {book_label}",
                "females": f"{role_labels['females']} {book_label}",
            }
        for genre_key, genre_label in JOBS_TYPE_TRANSLATIONS.items():
            data[f"{genre_key} {role_key}"] = {
                "males": f"{role_labels['males']} {genre_label}",
                "females": f"{role_labels['females']} {genre_label}",
            }

    return data


def _add_film_variants() -> dict[str, GenderedLabel]:
    """Create film-related job variants and return the number of generated entries."""
    """
    data: dict[str, GenderedLabel] = {}
    for film_key, film_label in film_keys_for_female.items():
        lowered_film_key = film_key.lower()
        for role_key, role_labels in FILM_ROLE_LABELS.items():
            data[role_key] = {"males": role_labels["males"], "females": role_labels["females"]}
            combo_key = f"{lowered_film_key} {role_key}"
            data[combo_key] = {
                "males": f"{role_labels['males']} {film_label}",
                "females": f"{role_labels['females']} {film_label}",
            }
    """

    data = {
        "film directors": {"males": "مخرجو أفلام", "females": "مخرجات أفلام"},
        "filmmakers": {"males": "صانعو أفلام", "females": "صانعات أفلام"},
        "film producers": {"males": "منتجو أفلام", "females": "منتجات أفلام"},
        "film critics": {"males": "نقاد أفلام", "females": "ناقدات أفلام"},
        "film editors": {"males": "محررو أفلام", "females": "محررات أفلام"},
        "documentary filmmakers": {"males": "صانعو أفلام وثائقية", "females": "صانعات أفلام وثائقية"},
        "documentary film directors": {"males": "مخرجو أفلام وثائقية", "females": "مخرجات أفلام وثائقية"},
        "animated film directors": {"males": "مخرجو أفلام رسوم متحركة", "females": "مخرجات أفلام رسوم متحركة"},
        "experimental filmmakers": {"males": "صانعو أفلام تجريبية", "females": "صانعات أفلام تجريبية"},
        "animated film producers": {"males": "منتجو أفلام رسوم متحركة", "females": "منتجات أفلام رسوم متحركة"},
        "pornographic film directors": {"males": "مخرجو أفلام إباحية", "females": "مخرجات أفلام إباحية"},
        "lgbtq film directors": {"males": "مخرجو أفلام إل جي بي تي كيو", "females": "مخرجات أفلام إل جي بي تي كيو"},
        "comedy film directors": {"males": "مخرجو أفلام كوميدية", "females": "مخرجات أفلام كوميدية"},
        "science fiction film directors": {"males": "مخرجو أفلام خيال علمي", "females": "مخرجات أفلام خيال علمي"},
        "fiction film directors": {"males": "مخرجو أفلام خيالية", "females": "مخرجات أفلام خيالية"},
        "pornographic film producers": {"males": "منتجو أفلام إباحية", "females": "منتجات أفلام إباحية"},
        "documentary film producers": {"males": "منتجو أفلام وثائقية", "females": "منتجات أفلام وثائقية"},
        "horror film directors": {"males": "مخرجو أفلام رعب", "females": "مخرجات أفلام رعب"},
        "film historians": {"males": "مؤرخو أفلام", "females": "مؤرخات أفلام"},
        "silent film directors": {"males": "مخرجو أفلام صامتة", "females": "مخرجات أفلام صامتة"},
        "action film directors": {"males": "مخرجو أفلام حركة", "females": "مخرجات أفلام حركة"},
        "cinema editors": {"males": "محررون سينمائون", "females": "محررات سينمائيات"},
        "silent film producers": {"males": "منتجو أفلام صامتة", "females": "منتجات أفلام صامتة"},
        "propaganda film directors": {"males": "مخرجو أفلام دعائية", "females": "مخرجات أفلام دعائية"},
        "war filmmakers": {"males": "صانعو أفلام حربية", "females": "صانعات أفلام حربية"},
        "fantasy film directors": {"males": "مخرجو أفلام فانتازيا", "females": "مخرجات أفلام فانتازيا"},
        "feminist filmmakers": {"males": "صانعو أفلام نسوية", "females": "صانعات أفلام نسوية"},
        "horror film producers": {"males": "منتجو أفلام رعب", "females": "منتجات أفلام رعب"},
        "japanese horror film directors": {"males": "مخرجو أفلام رعب يابانية", "females": "مخرجات أفلام رعب يابانية"},
        "lgbtq film producers": {"males": "منتجو أفلام إل جي بي تي كيو", "females": "منتجات أفلام إل جي بي تي كيو"},
        "parody film directors": {"males": "مخرجو أفلام ساخرة", "females": "مخرجات أفلام ساخرة"},
    }

    return data


def _add_singer_variants() -> dict[str, GenderedLabel]:
    """Add singer categories and stylistic combinations."""

    data: dict[str, GenderedLabel] = {
        "classical composers": {"males": "ملحنون كلاسيكيون", "females": "ملحنات كلاسيكيات"},
        "classical musicians": {"males": "موسيقيون كلاسيكيون", "females": "موسيقيات كلاسيكيات"},
        "classical pianists": {"males": "عازفو بيانو كلاسيكيون", "females": "عازفات بيانو كلاسيكيات"},
        "classical violinists": {"males": "عازفو كمان كلاسيكيون", "females": "عازفات كمان كلاسيكيات"},
        "classical cellists": {"males": "عازفو تشيلو كلاسيكيون", "females": "عازفات تشيلو كلاسيكيات"},
        "classical guitarists": {"males": "عازفو قيثارة كلاسيكيون", "females": "عازفات قيثارة كلاسيكيات"},
        "historical novelists": {"males": "روائيون تاريخيون", "females": "روائيات تاريخيات"},
        "classical singers": {"males": "مغنون كلاسيكيون", "females": "مغنيات كلاسيكيات"},
        "classical mandolinists": {"males": "عازفو مندولين كلاسيكيون", "females": "عازفات مندولين كلاسيكيات"},
        "classical saxophonists": {"males": "عازفو سكسفون كلاسيكيون", "females": "عازفات سكسفون كلاسيكيات"},
        "classical percussionists": {"males": "فنانون إيقاعيون كلاسيكيون", "females": "فنانات إيقاعيات كلاسيكيات"},
        "classical music critics": {"males": "نقاد موسيقى كلاسيكيون", "females": "ناقدات موسيقى كلاسيكيات"},
        "classical painters": {"males": "رسامون كلاسيكيون", "females": "رسامات كلاسيكيات"},
        "classical writers": {"males": "كتاب كلاسيكيون", "females": "كاتبات كلاسيكيات"},
        "classical choreographers": {"males": "مصممو رقص كلاسيكيون", "females": "مصممات رقص كلاسيكيات"},
        "classical dancers": {"males": "راقصون كلاسيكيون", "females": "راقصات كلاسيكيات"},
    }

    return data


def _build_jobs_new(
    female_jobs: Mapping[str, str],
) -> Dict[str, str]:
    """Build the flattened ``Jobs_new`` mapping used by legacy bots."""

    data: Dict[str, str] = {}

    for female_key, female_label in female_jobs.items():
        if female_label:
            lowered = female_key.lower()
            data[lowered] = female_label

    for nationality_key, nationality_label in Nat_mens.items():
        if nationality_label:
            data[f"{nationality_key.lower()} people"] = nationality_label

    data["people of the ottoman empire"] = "عثمانيون"

    return data


def _finalise_jobs_dataset() -> JobsDataset:
    """Construct the full jobs dataset from individual builders."""

    m_w_jobs: GenderedLabelMap = {}
    males_jobs: Dict[str, str] = {}
    females_jobs: Dict[str, str] = {}

    jobs_sources = _merge_jobs_sources()
    jobs_pp = _add_jobs_from_jobs2(jobs_sources)  # 1,369

    # sport_variants = _add_sport_variants(jobs_pp)                 # 4,107
    sport_variants = open_json_file("sport_variants_found.json")  # 35

    # people_variants = _add_jobs_people_variants()                 # 2,096
    people_variants = open_json_file("people_variants_found.json")  # 94

    merge_gendered_maps(m_w_jobs, MEN_WOMENS_JOBS_2)  # 534
    _load_activist_jobs(m_w_jobs, NAT_BEFORE_OCC)  # 95
    cycling_variants = _add_cycling_variants(NAT_BEFORE_OCC)  # 27
    film_variants = _add_film_variants()  # 1,881
    singer_variants = _add_singer_variants()  # 16

    m_w_jobs.update(MEN_WOMENS_SINGERS_BASED)  # 65
    m_w_jobs.update(MEN_WOMENS_SINGERS)  # 7,181 > to > 433
    m_w_jobs.update(jobs_pp)
    m_w_jobs.update(sport_variants)
    m_w_jobs.update(cycling_variants)
    m_w_jobs.update(people_variants)
    m_w_jobs.update(film_variants)
    m_w_jobs.update(singer_variants)

    merge_gendered_maps(m_w_jobs, PLAYERS_TO_MEN_WOMENS_JOBS)  # 1,345
    merge_gendered_maps(m_w_jobs, SPORT_JOB_VARIANTS)  # 61,486

    m_w_jobs["sports coaches"] = {"males": "مدربو رياضة", "females": "مدربات رياضة"}

    for job_key, labels in m_w_jobs.items():
        males_jobs[job_key] = labels["males"]
        if labels["females"]:
            females_jobs[job_key] = labels["females"]

    males_jobs["men's footballers"] = "لاعبو كرة قدم رجالية"

    # males_jobs["sports coaches"] = "مدربو رياضة"
    # females_jobs["sports coaches"] = "مدربات رياضة"

    males_jobs = {key: label for key, label in males_jobs.items() if label}

    len_print.data_len(
        "jobs.py",
        {
            "NAT_BEFORE_OCC_JOBS": NAT_BEFORE_OCC,
            "jobs_pp": jobs_pp,
            "jobs_sources": jobs_sources,
            "sport_variants": sport_variants,
            "cycling_variants": cycling_variants,
            "people_variants": people_variants,
            "film_variants": film_variants,
            "singer_variants": singer_variants,
        },
    )

    return JobsDataset(
        males_jobs=males_jobs,
        females_jobs=females_jobs,
    )


_DATASET = _finalise_jobs_dataset()

jobs_mens_data = _DATASET.males_jobs
jobs_womens_data = _DATASET.females_jobs
Jobs_new = _build_jobs_new(short_womens_jobs)

_len_result = {
    "jobs_mens_data": {"count": 97797, "size": "3.7 MiB"},  # "zoologists": "علماء حيوانات"
    "Jobs_key": {"count": 97784, "size": "3.7 MiB"},  # "zoologists": "علماء حيوانات"
    "Men_Womens_Jobs": {
        "count": 97796,
        "size": "3.7 MiB",
    },  # "zoologists": { "males": "علماء حيوانات", "females": "عالمات حيوانات" }
    "Jobs_new": {"count": 99104, "size": "3.7 MiB"},  # same as Jobs_key +
    "jobs_womens_data": {"count": 75244, "size": "1.8 MiB"},
}

len_print.data_len(
    "jobs.py",
    {
        "companies_to_jobs": companies_to_jobs,
        "jobs_mens_data": jobs_mens_data,
        "jobs_womens_data": jobs_womens_data,
        "Jobs_new": Jobs_new,
    },
)

__all__ = [
    "jobs_mens_data",
    "jobs_womens_data",
    "Jobs_new",
]
